<?php
/**
 * The featured layouts
 *
 * @package Technologist
 */

defined( 'WPINC' ) || exit;

/**
 * Class for featured layouts.
 */
class Technologist_Featured_Layouts extends Technologist_Base {

	/**
	 * Current layout.
	 *
	 * @var string
	 */
	public $current = null;

	/**
	 * Hold sections.
	 *
	 * @var array
	 */
	private $sections = null;

	/**
	 * The Construct
	 */
	public function __construct() {
		$this->sections = technologist_get_settings( 'featured_categories' );
	}

	/**
	 * Render layout
	 */
	public function render() {

		if ( empty( $this->sections ) ) {
			$this->current = [
				'layout'         => 'default',
				'posts_layout'   => 'layout-default',
				'excerpt_length' => 20,
				'unique_id'      => 'nothing',
				'is_latest'      => true,
			];

			get_template_part( 'template-parts/posts', 'default' );
			return;
		}

		$has_latest_posts = $this->has_latest_posts_section( $this->sections );

		foreach ( $this->sections as $section ) :

			$posts_layout = $section['blog_layout'];

			$layout = $posts_layout;
			if ( 'layout-default' === $posts_layout ) {
				$layout = 'default';
			}

			$category = $section['mts_featured_category'];

			if ( is_paged() ) {

				if ( $has_latest_posts && 'latest' !== $category ) {
					continue;
				}

				if ( 'layout-slider' === $layout || 'layout-html' === $layout ) {
					continue;
				}

				$this->current = [
					'layout'         => $layout,
					'posts_layout'   => $posts_layout,
					'category'       => $category,
					'excerpt_length' => $section['mts_featured_category_excerpt'],
					'unique_id'      => $section['unique_id'],
					'is_latest'      => false,
				];
				get_template_part( 'template-parts/posts', $layout );
				return;
			}

			$section = wp_parse_args( array_filter( $section ), [
				'blog_layout'                      => '',
				'mts_featured_category_postsnum'   => 6,
				'mts_featured_category_excerpt'    => 20,
				'mts_featured_category_background' => '',
				'mts_featured_category_margin'     => '',
				'mts_featured_category_padding'    => '',
				'unique_id'                        => '',
			] );

			if ( 'latest' !== $category ) {
				$this->category_posts( $category, $section['mts_featured_category_postsnum'] );
			}

			$this->current = [
				'layout'         => $layout,
				'category'       => $category,
				'unique_id'      => $section['unique_id'],
				'is_latest'      => 'latest' !== $category,
				'posts_layout'   => $posts_layout,
				'posts_count'    => $section['mts_featured_category_postsnum'],
				'excerpt_length' => $section['mts_featured_category_excerpt'],
			];
			if ( have_posts() ) {
				get_template_part( 'template-parts/posts', $layout );
			}

		endforeach;
	}

	/**
	 * Check if array of sections contains a Latest Posts section.
	 *
	 * @param array $sections Sections.
	 * @return boolean
	 */
	public function has_latest_posts_section( $sections ) {
		foreach ( $sections as $section ) {
			if ( 'latest' === $section['mts_featured_category'] ) {
				return true;
			}
		}
		return false;
	}

	/**
	 * Genrate post_container classes
	 */
	public function get_post_container_class() {
		$classes   = [];
		$classes[] = 'layout-' . $this->current['unique_id'];
		$classes[] = $this->current['layout'] . '-container';
		$classes[] = 'clearfix';

		echo join( ' ', $classes ); // phpcs:ignore
	}

	/**
	 * Set category in main query
	 *
	 * @param  int $category    Category ID.
	 * @param  int $posts_count Number of posts.
	 */
	public function category_posts( $category, $posts_count ) {
		global $wp_query;

		$wp_query = new WP_Query( 'ignore_sticky_posts=1&category_name=' . $category . '&posts_per_page=' . $posts_count ); // phpcs:ignore
	}

	/**
	 * Get section title.
	 *
	 * @param int $category Category id or name.
	 */
	public function get_section_title( $category = false ) {

		if ( ! technologist_get_settings( 'featured_category_title_' . $this->current['unique_id'] ) ) {
			return;
		}

		$post_title    = technologist_get_settings( 'featured_category_title_text_' . $this->current['unique_id'] );
		$category      = ! $category ? $this->current['category'] : $category;
		$category_name = technologist_get_cat_name( $category );
		$category_id   = get_cat_ID( $category_name );

		if ( 'latest' === $this->current['category'] ) {
			$category_name = 'Latest';
		}

		echo '<div class="title-container title-id-' . esc_html__( $this->current['unique_id'] ) . '">'; // phpcs:ignore

		$title = sprintf(
			'<h3 class="featured-category-title">
				<a href="%1$s" title="%2$s">%2$s</a>
			</h3>',
			esc_url( get_category_link( $category_id ) ),
			esc_attr( $category_name )
		);

		if ( $post_title['heading'] && $post_title['tag'] ) {
			$title = sprintf(
				'<%2$s class="featured-category-title"><span>%1$s</span></%2$s>',
				...array_values( $post_title ) // phpcs:ignore
			);
		}

		echo $title . '</div>'; // phpcs:ignore

	}

	/**
	 * Get sidebar
	 */
	public function get_sidebar() {

		$cat_name = __( 'Latest ', 'technologist' );

		if ( 'latest' !== $this->current['category'] ) {
			$cat_name = ucwords( technologist_get_cat_name( $this->current['category'] ) );
		}
		if ( 'default' === $this->current['layout'] ) {
			$this->current['layout'] = 'layout-default';
		}
		?>
		<aside id="sidebar" class="sidebar c-4-12 post-<?php echo esc_html( $this->current['layout'] ); ?>" role="complementary" itemscope itemtype="http://schema.org/WPSideBar">
			<?php
			dynamic_sidebar( sanitize_title( strtolower( 'post-' . $this->current['layout'] . $cat_name ) ) );
			?>
		</aside>
		<?php
	}

	/**
	 * Get post pagination
	 */
	public function get_post_pagination() {

		if ( ! $this->current['is_latest'] ) {
			technologist_pagination( technologist_get_settings( 'mts_pagenavigation_type' ) );
		}
		wp_reset_query(); // phpcs:ignore

	}
}
