<?php
/**
 * Dynamic CSS for the frontend.
 *
 * @package Technologist
 */

defined( 'WPINC' ) || exit;

/**
 * Helper function.
 * Merge and combine the CSS elements.
 *
 * @param  string|array $elements An array of our elements.
 *                                If we use a string then it is directly returned.
 * @return string
 */
function technologist_implode( $elements = [] ) {

	if ( ! is_array( $elements ) ) {
		return $elements;
	}

	// Make sure our values are unique.
	$elements = array_unique( $elements );

	// Sort elements alphabetically.
	// This way all duplicate items will be merged in the final CSS array.
	sort( $elements );

	// Implode items and return the value.
	return implode( ',', $elements );

}

/**
 * Maps elements from dynamic css to the selector.
 *
 * @param  array  $elements The elements.
 * @param  string $selector The selector.
 * @return array
 */
function technologist_map_selector( $elements, $selector ) {
	$array = [];

	foreach ( $elements as $element ) {
		$array[] = $element . $selector;
	}

	return $array;
}

/**
 * Map CSS selectors from values.
 *
 * @param array $css    Array of dynamic CSS.
 * @param array $values Array of values.
 */
function technologist_map_css_selectors( &$css, $values ) {
	if ( isset( $values['css-selectors'] ) ) {
		$elements = $values['css-selectors'];
		unset( $values['css-selectors'] );

		$css[ $elements ] = $values;
	}
}

/**
 * Merge CSS values.
 *
 * @param array $css    Array of dynamic CSS.
 * @param array $values Array of values.
 */
function technologist_merge_value( &$css, $values ) {
	foreach ( (array) $values as $id => $val ) {
		$css[ $id ] = $val;
	}
}

/**
 * Format of the $css array:
 * $css['media-query']['element']['property'] = value
 *
 * If no media query is required then set it to 'global'
 *
 * If we want to add multiple values for the same property then we have to make it an array like this:
 * $css[media-query][element]['property'][] = value1
 * $css[media-query][element]['property'][] = value2
 *
 * Multiple values defined as an array above will be parsed separately.
 */
function technologist_dynamic_css_array() {

	global $wp_version;

	$css       = [];
	$c_page_id = technologist()->get_page_id();

	// Site Background.
	$css['global']['html body'] = Technologist_Sanitize::background( technologist_get_settings( 'theme_background' ) );

	// Header Background.
	$css['global']['#site-header, .mobile-menu-active .navigation.mobile-menu-wrapper, .header-search-box #searchform'] = Technologist_Sanitize::background( technologist_get_settings( 'header_background' ) );

	// Logo Font.
	technologist_map_css_selectors( $css['global'], Technologist_Sanitize::typography( technologist_get_settings( 'technologist_logo' ) ) );
	// Footer Logo Font.
	technologist_map_css_selectors( $css['global'], Technologist_Sanitize::typography( technologist_get_settings( 'technologist_footer_logo' ) ) );
	// Primary Navigation font.
	technologist_map_css_selectors( $css['global'], Technologist_Sanitize::typography( technologist_get_settings( 'primary_navigation_font' ) ) );
	// Content Font.
	technologist_map_css_selectors( $css['global'], Technologist_Sanitize::typography( technologist_get_settings( 'content_font' ) ) );
	// Read more.
	technologist_map_css_selectors( $css['global'], Technologist_Sanitize::typography( technologist_get_settings( 'readmore_font' ) ) );
	// Pagination.
	technologist_map_css_selectors( $css['global'], Technologist_Sanitize::typography( technologist_get_settings( 'pagination_font' ) ) );
	// Archive Pages font.
	technologist_map_css_selectors( $css['global'], Technologist_Sanitize::typography( technologist_get_settings( 'archive_post_title_font' ) ) );
	technologist_map_css_selectors( $css['global'], Technologist_Sanitize::typography( technologist_get_settings( 'archive_post_excerpt_font' ) ) );
	technologist_map_css_selectors( $css['global'], Technologist_Sanitize::typography( technologist_get_settings( 'archive_meta_info_font' ) ) );
	// Single post category font.
	technologist_map_css_selectors( $css['global'], Technologist_Sanitize::typography( technologist_get_settings( 'single_categories_font' ) ) );
	// Single post title font.
	technologist_map_css_selectors( $css['global'], Technologist_Sanitize::typography( technologist_get_settings( 'single_title_font' ) ) );
	// Single post author info font.
	technologist_map_css_selectors( $css['global'], Technologist_Sanitize::typography( technologist_get_settings( 'single_author_meta_info_font' ) ) );
	// Single Page titles font.
	technologist_map_css_selectors( $css['global'], Technologist_Sanitize::typography( technologist_get_settings( 'single_page_titles_font' ) ) );
	// Single subscribe box.
	technologist_map_css_selectors( $css['global'], Technologist_Sanitize::typography( technologist_get_settings( 'single_subscribe_title_font' ) ) );
	technologist_map_css_selectors( $css['global'], Technologist_Sanitize::typography( technologist_get_settings( 'single_subscribe_text_font' ) ) );
	technologist_map_css_selectors( $css['global'], Technologist_Sanitize::typography( technologist_get_settings( 'single_subscribe_input_font' ) ) );
	technologist_map_css_selectors( $css['global'], Technologist_Sanitize::typography( technologist_get_settings( 'single_subscribe_submit_font' ) ) );
	technologist_map_css_selectors( $css['global'], Technologist_Sanitize::typography( technologist_get_settings( 'single_subscribe_small_text_font' ) ) );
	// Author Box.
	technologist_map_css_selectors( $css['global'], Technologist_Sanitize::typography( technologist_get_settings( 'authorbox_title_font' ) ) );
	technologist_map_css_selectors( $css['global'], Technologist_Sanitize::typography( technologist_get_settings( 'authorbox_author_name_font' ) ) );
	technologist_map_css_selectors( $css['global'], Technologist_Sanitize::typography( technologist_get_settings( 'authorbox_text_font' ) ) );
	// Subscribe widget title font.
	technologist_map_css_selectors( $css['global'], Technologist_Sanitize::typography( technologist_get_settings( 'subscribe_title_font' ) ) );
	// Fields font.
	technologist_map_css_selectors( $css['global'], Technologist_Sanitize::typography( technologist_get_settings( 'fields_font' ) ) );
	// H1 title in the content.
	technologist_map_css_selectors( $css['global'], Technologist_Sanitize::typography( technologist_get_settings( 'h1_headline' ) ) );
	// H2 title in the content.
	technologist_map_css_selectors( $css['global'], Technologist_Sanitize::typography( technologist_get_settings( 'h2_headline' ) ) );
	// H3 title in the content.
	technologist_map_css_selectors( $css['global'], Technologist_Sanitize::typography( technologist_get_settings( 'h3_headline' ) ) );
	// H4 title in the content.
	technologist_map_css_selectors( $css['global'], Technologist_Sanitize::typography( technologist_get_settings( 'h4_headline' ) ) );
	// H5 title in the content.
	technologist_map_css_selectors( $css['global'], Technologist_Sanitize::typography( technologist_get_settings( 'h5_headline' ) ) );
	// H6 title in the content.
	technologist_map_css_selectors( $css['global'], Technologist_Sanitize::typography( technologist_get_settings( 'h6_headline' ) ) );

	// Footer background.
	$css['global']['#site-footer'] = Technologist_Sanitize::background( technologist_get_settings( 'footer_background' ) );
	// Copyrights background.
	$css['global']['.copyrights'] = Technologist_Sanitize::background( technologist_get_settings( 'mts_copyrights_background' ) );

	technologist_dynamic_css_skin( $css );
	technologist_sidebar_position( $css );
	technologist_header( $css );
	technologist_header_search_box( $css );
	technologist_header_ticker( $css );
	technologist_sidebar_styling( $css );
	technologist_post_layouts( $css );
	technologist_post_pagination( $css );
	technologist_footer_section( $css );
	technologist_footer( $css );
	technologist_copyrights( $css );
	technologist_pages( $css );
	technologist_single( $css );
	technologist_single_social_buttons( $css );
	technologist_archive_post( $css );
	technologist_woo( $css );
	technologist_misc_css( $css );

	return apply_filters( 'technologist_dynamic_css_array', $css );
}

/**
 * Skin CSS
 *
 * @param array $css Array of dynamic CSS.
 */
function technologist_dynamic_css_skin( &$css ) {

	// Colors.
	$primary_color_scheme   = Technologist_Sanitize::color( technologist_get_settings( 'primary_color_scheme' ) );
	$secondary_color_scheme = Technologist_Sanitize::color( technologist_get_settings( 'secondary_color_scheme' ) );

	// Text Color.
	$elements = [
		'a',
		'body a:hover',
		'.textwidget a',
		'#wp-calendar td#today',
		'.pnavigation2 a',
		'#tabber .inside li a:hover',
		'.fn a',
		'#copyright-note a:hover',
		'.related-posts .title a:hover',
		'article ul li::before',
		'.pagination .nav-next a',
		'.pagination .nav-previous a',
		'.single .pagination a .current:hover',
		'.postauthor h5 a:hover',
		'#sidebar .widget .vertical-small .post-info a:hover',
		'#sidebar .widget li.horizontal-small .post-title a:hover',
		'#sidebar .widget .wp_review_tab_widget_content li a:hover',
		'#sidebar .widget.widget_categories li a:hover',
		'.aboutme-widget .aboutme-social a:hover',
		'.widget .sbutton',
		'.shareit-circular.standard .share-text',
		'.single_post .post-info.bottom a:hover',
		'.postauthor .author-social a:hover',
		'.shareit-circular.standard .social-icon:hover',
		'#primary-navigation li a:hover',
		'.header-search-icon:hover', // Search box.
		'.header-search-icon.active',
		'.latestPost .title a:hover',
		'.related-posts .latestPost .title a:hover',
		'.layout-2 .latestPost .title a:hover',
		'.layout-2 .latestPost .post-info.bottom span a:hover',
		'.layout-3 .latestPost.small .title a:hover',
		'.layout-3 .latestPost.small .post-info.bottom span a:hover',
		'.layout-default .latestPost .title a:hover',
		'.layout-default .latestPost .post-info.bottom span a:hover',
		'.toggle-menu .toggle-caret .fa',
		'.related-posts .post-info.bottom a:hover',
		'#commentform p .fa',
		'.woocommerce .flex-direction-nav li a:hover', // WooCommerce.
		'.woocommerce ul.products li.product .woocommerce-loop-product__title:hover',
		'.woocommerce-page ul.products li.product .woocommerce-loop-product__title:hover',
		'.woocommerce div.product p.price, .woocommerce div.product span.price',
		'.woocommerce ul.products li.product .price',
	];

	$css['global'][ technologist_implode( $elements ) ]['color'] = $primary_color_scheme;
	// social svg hover color.
	$css['global']['.shareit-circular.standard svg:hover']['fill'] = $primary_color_scheme;
	// Hover color.
	$elements = [
		'#sidebar .widget .vertical-small a:hover',
		'#sidebar .widget .review_thumb_large .entry-title a:hover',
		'#sidebar .widget li a:hover',
	];

	$css['global'][ technologist_implode( $elements ) ]['color'] = $primary_color_scheme . '!important';

	// Background Color.
	$elements = [
		'.button:hover',
		'.widget #wp-subscribe input.submit:hover',
		'.pace .pace-progress',
		'#mobile-menu-wrapper ul li a:hover',
		'.pagination a:hover',
		'.single .pagination a:hover .current',
		'.navigation #wpmm-megamenu .wpmm-pagination a',
		'.wpmm-megamenu-showing.wpmm-light-scheme',
		'#move-to-top:hover',
		'#tabber ul.tabs li a.selected',
		'.navigation ul .sfHover a',
		'.widget-slider .slide-caption',
		'.owl-prev:hover',
		'.owl-next:hover',
		'#wpmm-megamenu .review-total-only',
		'#searchsubmit',
		'.single-subscribe .widget #wp-subscribe input.submit:hover',
		'.widget .widget_wp_review_tab .review-total-only.large-thumb',
		'.widget.widget_categories li::before',
		'.widget.widget_archive li::before',
		'.single_post article .post ul li::before',
		'#commentform input#submit:hover',
		'#mtscontact_submit:hover',
		'#wb-mini-cart .button:hover',
		'.woocommerce div.product form.cart .button:hover',
		'.woocommerce-page div.product form.cart .button:hover',
		'.woocommerce button.button:hover',
		'.woocommerce-page button.button:hover',
		'.woocommerce a.checkout-button.button:hover',
		'.woocommerce-page #payment #place_order:hover',
		'.woocommerce .widget_price_filter .ui-slider .ui-slider-handle',
		'.woocommerce .widget_price_filter .ui-slider .ui-slider-range',
		'.woocommerce span.onsale',
		'.woocommerce .bypostauthor:after',
		'.woocommerce a.button:hover',
		'.woocommerce-page a.button:hover',
		'.woocommerce #review_form #respond .form-submit input:hover',
		'.woocommerce .widget.widget_product_search button[type="submit"]:hover',
		'.woocommerce-page .widget.widget_product_search button[type="submit"]:hover',
		'.woocommerce .woocommerce-widget-layered-nav-dropdown__submit:hover',
		'.woocommerce-account .woocommerce-MyAccount-navigation li.is-active',
	];

	$css['global'][ technologist_implode( $elements ) ]['background-color'] = $primary_color_scheme;

	// Border Color.
	$elements = [
		'.f-widget .widget.widget_search #s:focus',
	];

	$css['global'][ technologist_implode( $elements ) ]['border-color'] = $primary_color_scheme;

	// Secondary Text Color.
	$elements = [
		'.reply a',
		'.aboutme-widget .author-name h4',
		'.aboutme-widget .aboutme-social a',
		'.f-widget .tagcloud a',
		'.f-widget .widget .wpt_widget_content #tags-tab-content ul li a',
		'a#pull',
		'.star-rating', // WooCommerce.
		'.woocommerce-page nav.woocommerce-pagination ul li a',
		'.woocommerce nav.woocommerce-pagination ul li a',
	];

	$css['global'][ technologist_implode( $elements ) ]['color'] = $secondary_color_scheme;

	// Secondary Background Color.
	$elements = [
		'.tagcloud a:hover',
		'.widget .wpt_widget_content #tags-tab-content ul li a:hover',
		'.tags a:hover',
		'#commentform input#submit',
		'#mtscontact_submit',
		'.advanced-recent-posts li.no-thumb::after', // widget counter.
		'.author-posts-widget li.no-thumb::after',
		'.category-posts li.no-thumb::after',
		'.popular-posts li.no-thumb::after',
		'.related-posts-widget li.no-thumb::after',
		'.widget .wp_review_tab_widget_content .tab_title.selected::before',
		'.widget .wpt_widget_content .tab_title.selected::before',
		'pre',
		'.woocommerce a.button', // WooCommerce.
		'.woocommerce-page a.button',
		'.woocommerce button.button',
		'.woocommerce-page button.button',
		'.woocommerce input.button',
		'.woocommerce-page input.button',
		'.woocommerce #respond input#submit',
		'.woocommerce-page #respond input#submit',
		'.woocommerce #content input.button',
		'.woocommerce-page #content input.button',
		'.woocommerce #respond input#submit.alt.disabled',
		'.woocommerce #respond input#submit.alt:disabled[disabled]',
		'.woocommerce a.button.alt:disabled',
		'.woocommerce a.button.alt:disabled[disabled]',
		'.woocommerce button.button.alt.disabled',
		'.woocommerce button.button.alt:disabled[disabled]',
		'#add_payment_method .wc-proceed-to-checkout a.checkout-button',
		'.woocommerce-cart .wc-proceed-to-checkout a.checkout-button',
		'.woocommerce-checkout .wc-proceed-to-checkout a.checkout-button',
		'.woocommerce a.button.alt',
		'.woocommerce button.button.alt',
		'.woocommerce input.button.alt',
		'.woocommerce .woocommerce-widget-layered-nav-dropdown__submit',
		'.woocommerce .widget.widget_product_search button[type="submit"]',
		'.woocommerce-page .widget.widget_product_search button[type="submit"]',
		'.woocommerce div.product form.cart .button',
	];

	$css['global'][ technologist_implode( $elements ) ]['background-color'] = $secondary_color_scheme;

	// Secondary Border Color.
	$elements = [
		'#commentform textarea:hover',
		'#commentform textarea:focus',
		'input#author:hover',
		'input#author:focus',
		'input#email:hover',
		'input#email:focus',
		'input#url:hover',
		'input#url:focus',
		'.contact-form textarea:hover',
		'.contact-form textarea:focus',
		'.contact-form input[type="text"]:hover',
		'.contact-form input[type="text"]:focus',
	];

	$css['global'][ technologist_implode( $elements ) ]['border-color'] = $secondary_color_scheme;

}

/**
 * Sidebar Position
 *
 * @param array $css Array of dynamic CSS.
 */
function technologist_sidebar_position( &$css ) {

	// Sidebar position.
	$sidebar_position = technologist_get_settings( 'theme_layout' );

	$sidebar_metabox_location = '';
	if ( is_page() || is_single() ) {
		$sidebar_metabox_location = get_post_meta( get_the_ID(), '_mts_sidebar_location', true );
	}

	if ( 'right' !== $sidebar_metabox_location && ( 'sclayout' === $sidebar_position || 'left' === $sidebar_metabox_location ) ) {
		$css['global']['.article']['float']                = 'right';
		$css['global']['.sidebar.c-4-12']['float']         = 'left';
		$css['global']['.sidebar.c-4-12']['padding-right'] = 0;

		if ( null !== technologist_get_settings( 'mts_social_button_position' ) && 'floating' === technologist_get_settings( 'mts_social_button_position' ) ) {

			$shareit_class = [
				'.sclayout .shareit.shareit-default.floating',
				'.sclayout .shareit.standard.floating',
				'.sclayout .shareit.shareit-circular.floating',
			];

			$css['global'][ technologist_implode( $shareit_class ) ]['left']  = 'auto';
			$css['global'][ technologist_implode( $shareit_class ) ]['right'] = '0px';

			$css['global'][ technologist_implode( $shareit_class ) ]['margin-left']  = '0px';
			$css['global'][ technologist_implode( $shareit_class ) ]['margin-right'] = technologist_px2rem( '70px' );
		}
	}
	if ( 'mts_nosidebar' === mts_custom_sidebar() ) {
		$css['global']['.single-full-header']['width'] = '100%';
	}
}

/**
 * Header
 *
 * @param array $css Array of dynamic CSS.
 */
function technologist_header( &$css ) {

	$header_icons  = technologist_get_settings( 'header_social_icons' );
	$header_layout = technologist_get_settings( 'header_styles' );

	// Header.
	// Header layout default.
	if ( 'header-default' === $header_layout ) {
		technologist_merge_value( $css['global']['#site-header'], Technologist_Sanitize::margin( technologist_get_settings( 'header_margin' ) ) );
		technologist_merge_value( $css['global']['#site-header'], Technologist_Sanitize::padding( technologist_get_settings( 'header_padding' ) ) );
	}

	// Header Border.
	$header_border = Technologist_Sanitize::border( technologist_get_settings( 'header_border' ) );
	$css['global']['#site-header, .sticky-navigation-active.header-default'][ $header_border['direction'] ] = $header_border['value'];

	// Nav styling.
	// Nav color.
	$css['global']['#primary-navigation .navigation ul ul a']['color'] = Technologist_Sanitize::color( technologist_get_settings( 'main_navigation_dropdown_color' ) );

	$css['global']['#primary-navigation .navigation ul ul a:hover']['color'] = Technologist_Sanitize::color( technologist_get_settings( 'main_navigation_dropdown_hover_color' ) );

	// Nav Dropdown Background.
	$css['global']['.navigation ul ul']['background-color'] = Technologist_Sanitize::color( technologist_get_settings( 'main_nav_dropdown_bg' ) );

	// Nav margin and Padding.
	technologist_merge_value( $css['global']['#primary-navigation'], Technologist_Sanitize::margin( technologist_get_settings( 'header_nav_margin' ) ) );
	technologist_merge_value( $css['global']['#primary-navigation li a'], Technologist_Sanitize::padding( technologist_get_settings( 'header_nav_padding' ) ) );

	// Header layout 2.
	if ( 'header-layout2' === $header_layout ) {

		technologist_merge_value( $css['global']['#header'], Technologist_Sanitize::margin( technologist_get_settings( 'header2_nav_margin' ) ) );

		technologist_merge_value( $css['global']['#header'], Technologist_Sanitize::padding( technologist_get_settings( 'header2_nav_padding' ) ) );

	}

	// Social icons.
	if ( $header_icons && is_array( $header_icons ) ) {

		foreach ( $header_icons as $header_icon ) {

			$css['global'][ '.header-social-icons a.header-' . $header_icon['header_icon'] ]['background-color'] = Technologist_Sanitize::color( $header_icon['header_icon_bgcolor'] );

			$css['global'][ '.header-social-icons a.header-' . $header_icon['header_icon'] . ':hover' ]['background-color'] = Technologist_Sanitize::color( $header_icon['header_icon_hover_bgcolor'] );

			$css['global'][ '.header-social-icons a.header-' . $header_icon['header_icon'] ]['color'] = Technologist_Sanitize::color( $header_icon['header_icon_color'] );

			$css['global'][ '.header-social-icons a.header-' . $header_icon['header_icon'] . ':hover' ]['color'] = Technologist_Sanitize::color( $header_icon['header_icon_hover_color'] );

			technologist_merge_value( $css['global'][ '.header-social-icons a.header-' . $header_icon['header_icon'] ], Technologist_Sanitize::margin( $header_icon['header_icon_margin'] ) );

			technologist_merge_value( $css['global'][ '.header-social-icons a.header-' . $header_icon['header_icon'] ], Technologist_Sanitize::padding( $header_icon['header_icon_padding'] ) );

			$css['global'][ '.header-social-icons a.header-' . $header_icon['header_icon'] ]['border-radius'] = Technologist_Sanitize::size( $header_icon['header_icon_border_radius'] . 'px' );

		}
	}

	// Header Ad.
	technologist_merge_value( $css['global']['.widget-header'], Technologist_Sanitize::margin( technologist_get_settings( 'mts_header_adcode_margin' ) ) );

	// Ad-Blocker.
	$css['global']['.navigation-banner']['background'] = Technologist_Sanitize::color( technologist_get_settings( 'navigation_ad_background' ) );

	// Floating Navigation Responsive.
	if ( ! technologist_get_settings( 'sticky_responsive_nav' ) ) {
		$css['@media screen and (max-width: 865px)']['#catcher']['height']                           = '0px!important';
		$css['@media screen and (max-width: 865px)']['.sticky-navigation-active']['position']        = 'relative!important';
		$css['@media screen and (max-width: 865px)']['.sticky-navigation-active']['top']             = '0px!important';
		$css['@media screen and (max-width: 865px)']['.admin-bar .sticky-navigation-active ']['top'] = '0px!important';
	}
}

/**
 * Header Search Box Styling
 *
 * @param array $css Array of dynamic CSS.
 */
function technologist_header_search_box( &$css ) {

	$css['global']['.header-search-icon svg path']['fill'] = Technologist_Sanitize::color( technologist_get_settings( 'search_icon_color' ) );

	// Search box position.
	$css['global']['.header-search-box']['top'] = Technologist_Sanitize::size( technologist_get_settings( 'search_box_position' ) . 'px' );

	technologist_map_css_selectors( $css['global'], Technologist_Sanitize::typography( technologist_get_settings( 'search_box_font' ) ) );

}

/**
 * Header Animated Ticker
 *
 * @param array $css Array of dynamic CSS.
 */
function technologist_header_ticker( &$css ) {

	$css['global']['.trending-ticker'] = Technologist_Sanitize::background( technologist_get_settings( 'ticker_background' ) );

	// Typography.
	technologist_map_css_selectors( $css['global'], Technologist_Sanitize::typography( technologist_get_settings( 'ticker_title_font' ) ) );
	technologist_map_css_selectors( $css['global'], Technologist_Sanitize::typography( technologist_get_settings( 'ticker_posts_font' ) ) );

}

/**
 * Social Share Styling
 *
 * @param array $css Array of dynamic CSS.
 */
function technologist_single_social_buttons( &$css ) {

	// Social share.
	$css['global']['.shareit.floating'] = Technologist_Sanitize::background( technologist_get_settings( 'social_styling_background' ) );
	technologist_merge_value( $css['global']['.shareit.floating'], Technologist_Sanitize::margin( technologist_get_settings( 'social_styling_margin' ) ) );

	// Social share border.
	$social_border = Technologist_Sanitize::border( technologist_get_settings( 'social_styling_border' ) );
	$css['global']['.shareit.floating'][ $social_border ['direction'] ] = $social_border ['value'];

	$social_button_layout   = technologist_get_settings( 'social_button_layout' );
	$social_button_position = technologist_get_settings( 'social_floating_button_position' );
	if ( 'default' === $social_button_layout ) {
		$share_class = '.shareit.shareit-' . $social_button_layout . '.floating';
	} else {
		$share_class = '.shareit.' . $social_button_layout . '.floating';
	}
	if ( ! empty( $social_button_position ) && is_array( $social_button_position ) ) {
		foreach ( $social_button_position as $key => $position ) {
			$css['global'][ $share_class ][ $key ] = $position;
		}
	}

	// Typography.
	technologist_map_css_selectors( $css['global'], Technologist_Sanitize::typography( technologist_get_settings( 'social_share_font' ) ) );
}

/**
 * Sidebar styling
 *
 * @param array $css Array of dynamic CSS.
 */
function technologist_sidebar_styling( &$css ) {

	// Sidebar title.
	$sidebar_title = '#sidebar .widget h3';

	$css['global'][ $sidebar_title . ' span' ] = Technologist_Sanitize::background( technologist_get_settings( 'sidebar_title_styling_background' ) );

	// Margin and Padding.
	technologist_merge_value( $css['global'][ $sidebar_title . ' span' ], Technologist_Sanitize::padding( technologist_get_settings( 'sidebar_title_styling_padding' ) ) );
	technologist_merge_value( $css['global'][ $sidebar_title ], Technologist_Sanitize::margin( technologist_get_settings( 'sidebar_title_styling_margin' ) ) );

	// Title border.
	$sidebar_title_border = Technologist_Sanitize::border( technologist_get_settings( 'widget_title_border' ) );
	$css['global'][ $sidebar_title ][ $sidebar_title_border['direction'] ] = $sidebar_title_border['value'];

	// Sidebar.
	technologist_merge_value( $css['global']['.sidebar .widget'], Technologist_Sanitize::background( technologist_get_settings( 'sidebar_styling_background' ) ) );
	technologist_merge_value( $css['global']['.sidebar .widget'], Technologist_Sanitize::margin( technologist_get_settings( 'sidebar_styling_margin' ) ) );
	technologist_merge_value( $css['global']['.sidebar .widget'], Technologist_Sanitize::padding( technologist_get_settings( 'sidebar_styling_padding' ) ) );

	// Widget catrgories background.
	$css['global']['.widget .vertical-small .thecategory a']['background-color'] = Technologist_Sanitize::color( technologist_get_settings( 'sidebar_category_bgcolor' ) );

	// Sidebar border.
	$sidebar_border = Technologist_Sanitize::border( technologist_get_settings( 'sidebar_styling_border' ) );
	$css['global']['.sidebar .widget'][ $sidebar_border['direction'] ] = $sidebar_border['value'];

	// Border Radius.
	$css['global']['.sidebar .widget']['border-radius'] = Technologist_Sanitize::size( technologist_get_settings( 'sidebar_styling_border_radius' ) . 'px' );

	// Typography.
	// Sidebar widget title font.
	technologist_map_css_selectors( $css['global'], Technologist_Sanitize::typography( technologist_get_settings( 'sidebar_title_font' ) ) );
	technologist_map_css_selectors( $css['global'], Technologist_Sanitize::typography( technologist_get_settings( 'sidebar_buttons_font' ) ) );
	technologist_map_css_selectors( $css['global'], Technologist_Sanitize::typography( technologist_get_settings( 'submit_button_font' ) ) );

	// Sidebar widget font.
	technologist_map_css_selectors( $css['global'], Technologist_Sanitize::typography( technologist_get_settings( 'mts_widget_links' ) ) );
	technologist_map_css_selectors( $css['global'], Technologist_Sanitize::typography( technologist_get_settings( 'default_widget_links' ) ) );
	technologist_map_css_selectors( $css['global'], Technologist_Sanitize::typography( technologist_get_settings( 'sidebar_url_bigthumb' ) ) );
	technologist_map_css_selectors( $css['global'], Technologist_Sanitize::typography( technologist_get_settings( 'sidebar_font' ) ) );
	technologist_map_css_selectors( $css['global'], Technologist_Sanitize::typography( technologist_get_settings( 'sidebar_font_bigthumb' ) ) );
	technologist_map_css_selectors( $css['global'], Technologist_Sanitize::typography( technologist_get_settings( 'sidebar_categories_font' ) ) );
	technologist_map_css_selectors( $css['global'], Technologist_Sanitize::typography( technologist_get_settings( 'sidebar_postinfo_font' ) ) );
	technologist_map_css_selectors( $css['global'], Technologist_Sanitize::typography( technologist_get_settings( 'sidebar_postinfo_font_bigthumb' ) ) );

	$sidebar_meta_info_class = '#sidebar .post-info > span:after';
	$sidebar_meta_info_font  = technologist_get_settings( 'sidebar_postinfo_font' );
	// Sidebar Meta divider.
	$css['global'][ $sidebar_meta_info_class ]['background-color'] = Technologist_Sanitize::color( $sidebar_meta_info_font['color'] );

	/**
	 * Subscribe widgets.
	 */
	$subscribe_classes = [
		'.sidebar .widget #wp-subscribe',
		'footer .widget #wp-subscribe',
	];
	$fields_classes    = [
		'.sidebar .widget #wp-subscribe input.email-field',
		'.sidebar .widget #wp-subscribe input.name-field',
		'footer .widget #wp-subscribe input.email-field',
		'footer .widget #wp-subscribe input.name-field',
	];
	$submit_classes    = [
		'.sidebar .widget #wp-subscribe input.submit',
		'footer .widget #wp-subscribe input.submit',
	];

	$css['global'][ technologist_implode( $subscribe_classes ) ] = Technologist_Sanitize::background( technologist_get_settings( 'subscribe_widget_background' ) );

	// Padding.
	technologist_merge_value( $css['global'][ technologist_implode( $subscribe_classes ) ], Technologist_Sanitize::padding( technologist_get_settings( 'subscribe_widget_padding' ) ) );

	// Fields background color.
	$css['global'][ technologist_implode( $fields_classes ) ]['background-color'] = Technologist_Sanitize::color( technologist_get_settings( 'subscribe_widget_fields_color' ) );

	// Submit button background color.
	$css['global'][ technologist_implode( $submit_classes ) ]['background-color'] = Technologist_Sanitize::color( technologist_get_settings( 'subscribe_widget_button_color' ) );

	// Border.
	$subscribe_border = Technologist_Sanitize::border( technologist_get_settings( 'subscribe_widget_field_border' ) );
	$css['global'][ technologist_implode( $fields_classes ) ][ $subscribe_border['direction'] ] = $subscribe_border['value'];

	// Border Radius.
	$css['global'][ technologist_implode( $subscribe_classes ) ]['border-radius'] = Technologist_Sanitize::size( technologist_get_settings( 'subscribe_widget_border_radius' ) . 'px' );

	// Typography.
	technologist_map_css_selectors( $css['global'], Technologist_Sanitize::typography( technologist_get_settings( 'subscribe_widget_title_font' ) ) );
	technologist_map_css_selectors( $css['global'], Technologist_Sanitize::typography( technologist_get_settings( 'subscribe_widget_text_font' ) ) );
	technologist_map_css_selectors( $css['global'], Technologist_Sanitize::typography( technologist_get_settings( 'subscribe_widget_fields_font' ) ) );

	/**
	 * Tab widgets.
	 */
	technologist_map_css_selectors( $css['global'], Technologist_Sanitize::typography( technologist_get_settings( 'tabs_title_font' ) ) );

	// Tags.
	$css['global']['.tagcloud a, .widget .wpt_widget_content #tags-tab-content ul li a']['background-color'] = Technologist_Sanitize::color( technologist_get_settings( 'tags_bgcolor' ) );

	/**
	 * Footer widget settings.
	 */
	technologist_merge_value( $css['global']['.f-widget .widget'], Technologist_Sanitize::background( technologist_get_settings( 'f_widget_background' ) ) );
	technologist_merge_value( $css['global']['.f-widget .widget'], Technologist_Sanitize::margin( technologist_get_settings( 'f_widget_margin' ) ) );
	technologist_merge_value( $css['global']['.f-widget .widget'], Technologist_Sanitize::padding( technologist_get_settings( 'f_widget_padding' ) ) );

	$widgets_margin = Technologist_Sanitize::margin( technologist_get_settings( 'f_widget_margin' ) );
	$footer_widget  = '.footer-widgets .f-widget';
	// Widgets Margin.
	$css['global'][ $footer_widget ]['margin-bottom'] = '-' . $widgets_margin['margin-bottom'];

	// Border.
	$f_widget_border = Technologist_Sanitize::border( technologist_get_settings( 'f_widget_border' ) );
	$css['global']['.f-widget .widget'][ $f_widget_border['direction'] ] = $f_widget_border['value'];

	// Border Radius.
	$css['global']['.f-widget .widget']['border-radius'] = Technologist_Sanitize::size( technologist_get_settings( 'f_widget_border_radius' ) . 'px' );

	// Box shadow.
	if ( ! technologist_get_settings( 'f_widget_shadow' ) ) {
		$css['global']['.f-widget .widget']['box-shadow'] = 'none';
	}

	// Typography.
	// Footer widget title font.
	technologist_map_css_selectors( $css['global'], Technologist_Sanitize::typography( technologist_get_settings( 'footer_technologist_logo' ) ) );
	technologist_map_css_selectors( $css['global'], Technologist_Sanitize::typography( technologist_get_settings( 'top_footer_title_font' ) ) );
	// Footer link font.
	technologist_map_css_selectors( $css['global'], Technologist_Sanitize::typography( technologist_get_settings( 'top_footer_link_font' ) ) );
	// Footer MTS link font.
	technologist_map_css_selectors( $css['global'], Technologist_Sanitize::typography( technologist_get_settings( 'mts_footer_widget_links' ) ) );
	// Footer widget font.
	technologist_map_css_selectors( $css['global'], Technologist_Sanitize::typography( technologist_get_settings( 'top_footer_font' ) ) );
	technologist_map_css_selectors( $css['global'], Technologist_Sanitize::typography( technologist_get_settings( 'footer_metainfo_font' ) ) );
	// Copyrights section font.
	technologist_map_css_selectors( $css['global'], Technologist_Sanitize::typography( technologist_get_settings( 'copyrights_font' ) ) );

	$footer_meta_info_class = '#site-footer .post-info > span:after';
	$footer_meta_info_font  = technologist_get_settings( 'footer_metainfo_font' );
	// bullets color.
	$css['global'][ $footer_meta_info_class ]['background-color'] = Technologist_Sanitize::color( $footer_meta_info_font['color'] );

}

/**
 * Layout CSS
 *
 * @param array $css Array of dynamic CSS.
 */
function technologist_post_layouts( &$css ) {

	// Post Layouts.
	$features = technologist_get_settings( 'featured_categories' );

	if ( $features && is_array( $features ) ) {

		foreach ( $features as $feature ) {

			if ( ! isset( $feature['unique_id'] ) ) {
				continue;
			}

			$category     = $feature['mts_featured_category'];
			$posts_layout = isset( $feature['blog_layout'] ) ? $feature['blog_layout'] : 'layout-default';
			$unique_id    = $feature['unique_id'];

			if ( 'layout-default' === $posts_layout ) :
				$posts_layout = 'default';
			endif;

			// Section title align.
			$post_title_align = technologist_get_settings( 'post_title_alignment_' . $unique_id );

			// Post area.
			$cat_class = 'cat-latest';
			if ( 'latest' !== $category ) {
				$category  = get_term_by( 'slug', $category, 'category' );
				$cat_class = sanitize_key( $category->name );
			}

			$title_class = [
				'.title-container.title-id-' . $unique_id . ' .featured-category-title a',
				'.title-container.title-id-' . $unique_id . ' .featured-category-title span',
			];

			// Section title background.
			$css['global'][ technologist_implode( $title_class ) ] = Technologist_Sanitize::background( technologist_get_settings( 'featured_category_title_background_' . $unique_id ) );

			// Section title margin & padding.
			technologist_merge_value( $css['global'][ technologist_implode( $title_class ) ], Technologist_Sanitize::margin( technologist_get_settings( 'featured_category_title_margin_' . $unique_id ) ) );
			technologist_merge_value( $css['global'][ technologist_implode( $title_class ) ], Technologist_Sanitize::padding( technologist_get_settings( 'featured_category_title_padding_' . $unique_id ) ) );

			// Section title border.
			$post_title_border = Technologist_Sanitize::border( technologist_get_settings( 'post_title_border_' . $unique_id ) );
			$css['global'][ '.title-container.title-id-' . $unique_id . ' .featured-category-title' ][ $post_title_border['direction'] ] = $post_title_border['value'];

			// Title alignment.
			$align_class = '.title-container.title-id-' . $unique_id;
			if ( 'center' === $post_title_align ) :
				$css['global'][ $align_class ]['text-align'] = 'center';
			elseif ( 'right' === $post_title_align ) :
				$css['global'][ $align_class ]['text-align']              = 'right';
				$css['global'][ $align_class . ' + .view-more' ]['left']  = '0';
				$css['global'][ $align_class . ' + .view-more' ]['right'] = 'auto';
			endif;

			technologist_map_css_selectors( $css['global'], Technologist_Sanitize::typography( technologist_get_settings( 'featured_category_title_font_' . $unique_id ) ) );

			$post_class = '.layout-' . $unique_id;

			if ( 'layout-default' === $posts_layout ) {
				$post_class = '.layout-' . $unique_id . '.default-container';
			}

			// Post border.
			$post_border = Technologist_Sanitize::border( technologist_get_settings( 'post_border_' . $unique_id ) );
			$css['global'][ $post_class ][ $post_border['direction'] ] = $post_border['value'];

			/**
			 * Meta info
			 */
			technologist_map_css_selectors( $css['global'], Technologist_Sanitize::typography( technologist_get_settings( 'categories_font_' . $unique_id ) ) );

			technologist_map_css_selectors( $css['global'], Technologist_Sanitize::typography( technologist_get_settings( 'meta_info_font_' . $unique_id ) ) );

			if ( 'layout-3' === $posts_layout ) {
				technologist_map_css_selectors( $css['global'], Technologist_Sanitize::typography( technologist_get_settings( 'small_categories_font_' . $unique_id ) ) );
				technologist_map_css_selectors( $css['global'], Technologist_Sanitize::typography( technologist_get_settings( 'small_meta_info_font_' . $unique_id ) ) );
			}

			// Background.
			if ( ! in_array( $posts_layout, [ 'layout-default', 'layout-html' ], true ) ) {
				$css['global'][ $post_class ] = Technologist_Sanitize::background( technologist_get_settings( 'post_background_' . $unique_id ) );
			}
			// Background color 2.
			if ( 'layout-1' === $posts_layout ) {

				$css['global'][ $post_class . '.layout-1-container::after' ]['background-color'] = Technologist_Sanitize::color( technologist_get_settings( 'post_bg2_color_' . $unique_id ) );

				$css['global'][ $post_class . '.layout-1-container::after' ]['height'] = Technologist_Sanitize::size( technologist_get_settings( 'post_bg2_height_' . $unique_id ) . '%' );

			}
			// Category Background.
			$css['global'][ '.layout-' . $unique_id . ' .latestPost .post-info.top a' ]['background-color'] = Technologist_Sanitize::color( technologist_get_settings( 'categories_bg_color_' . $unique_id ) );

			technologist_map_css_selectors( $css['global'], Technologist_Sanitize::typography( technologist_get_settings( 'post_title_font_' . $unique_id ) ) );
			technologist_map_css_selectors( $css['global'], Technologist_Sanitize::typography( technologist_get_settings( 'post_excerpt_font_' . $unique_id ) ) );

			if ( in_array( $posts_layout, [ 'layout-1', 'layout-3' ], true ) ) {
				technologist_map_css_selectors( $css['global'], Technologist_Sanitize::typography( technologist_get_settings( 'small_post_title_font_' . $unique_id ) ) );
			}

			// Margin and Padding.
			technologist_merge_value( $css['global'][ $post_class ], Technologist_Sanitize::margin( technologist_get_settings( 'post_margin_' . $unique_id ) ) );
			technologist_merge_value( $css['global'][ $post_class ], Technologist_Sanitize::padding( technologist_get_settings( 'post_padding_' . $unique_id ) ) );

			// Post Meta Info Divider.
			$post_meta_info_class = '.layout-' . $unique_id . ' .latestPost .post-info > span:after';
			$post_meta_info_font  = technologist_get_settings( 'meta_info_font_' . $unique_id );

			// Background color.
			$css['global'][ $post_meta_info_class ]['background-color'] = Technologist_Sanitize::color( $post_meta_info_font['color'] );

			// Thumbanil Border Radius.
			$border_radius_class = [
				'.layout-' . $unique_id . ' .latestPost .featured-thumbnail img',
				'.layout-' . $unique_id . '.layout-1-container .latestPost',
				'.layout-' . $unique_id . '.layout-3-container .latestPost',
				'.layout-' . $unique_id . '.default-container .latestPost[class*="format-"] #featured-thumbnail',
				'.layout-' . $unique_id . '.layout-2-container .latestPost[class*="format-"] #featured-thumbnail',
				'.layout-' . $unique_id . '.layout-3-container .right-posts .latestPost[class*="format-"] #featured-thumbnail',
			];
			$css['global'][ technologist_implode( $border_radius_class ) ]['border-radius'] = Technologist_Sanitize::size( technologist_get_settings( 'post_image_border_radius_' . $unique_id ) . 'px' );

		}
	}
}

/**
 * Pagination
 *
 * @param array $css Array of dynamic CSS.
 */
function technologist_post_pagination( &$css ) {

	// Pagination Active class.
	$pagination_class_active = [
		'.pace .pace-progress',
		'.page-numbers.current',
		'.pagination a:hover',
	];
	$pagination_class        = [
		'.pagination a',
		'.single .pagination > .current .currenttext',
		'.pagination .page-numbers.dots',
	];
	technologist_merge_value( $css['global'][ technologist_implode( array_merge( $pagination_class_active, $pagination_class ) ) ], Technologist_Sanitize::margin( technologist_get_settings( 'mts_pagenavigation_margin' ) ) );

	// Pagination.
	$css['global'][ technologist_implode( $pagination_class ) ] = Technologist_Sanitize::background( technologist_get_settings( 'mts_pagenavigation_bgcolor' ) );

	$css['global'][ technologist_implode( $pagination_class_active ) ] = Technologist_Sanitize::background( technologist_get_settings( 'mts_pagenavigation_hover_bgcolor' ) );

	$css['global']['.page-numbers.current'] = Technologist_Sanitize::background( technologist_get_settings( 'mts_pagenavigation_active_bgcolor' ) );

	$css['global'][ technologist_implode( $pagination_class ) ]['color'] = Technologist_Sanitize::color( technologist_get_settings( 'mts_pagenavigation_color' ) );

	$css['global'][ technologist_implode( $pagination_class_active ) ]['color'] = Technologist_Sanitize::color( technologist_get_settings( 'mts_pagenavigation_hover_color' ) );

	technologist_merge_value( $css['global'][ technologist_implode( array_merge( $pagination_class_active, $pagination_class ) ) ], Technologist_Sanitize::padding( technologist_get_settings( 'mts_pagenavigation_padding' ) ) );

	// Load More.
	$css['global']['#load-posts > a, .pagination .nav-next a, .pagination .nav-previous a'] = Technologist_Sanitize::background( technologist_get_settings( 'load_more_bgcolor' ) );

	$css['global']['#load-posts a:hover, .pagination .nav-next a:hover, .pagination .nav-previous a:hover'] = Technologist_Sanitize::background( technologist_get_settings( 'load_more_hover_bgcolor' ) );

	$css['global']['#load-posts a:hover, .pagination .nav-next a:hover, .pagination .nav-previous a:hover']['color'] = Technologist_Sanitize::color( technologist_get_settings( 'load_more_hover_color' ) );

	// Typography.
	technologist_map_css_selectors( $css['global'], Technologist_Sanitize::typography( technologist_get_settings( 'load_more_font' ) ) );

	technologist_merge_value( $css['global']['#load-posts a'], Technologist_Sanitize::padding( technologist_get_settings( 'load_more_padding' ) ) );
	$css['global']['#load-posts a, .pagination .nav-next a, .pagination .nav-previous a']['color'] = Technologist_Sanitize::color( technologist_get_settings( 'load_more_color' ) );

	$border_radius_class   = $pagination_class;
	$border_radius_class[] = '#load-posts a';

	// Border radius.
	$css['global'][ technologist_implode( array_merge( $pagination_class_active, $border_radius_class ) ) ]['border-radius'] = Technologist_Sanitize::size( technologist_get_settings( 'mts_pagenavigation_border_radius' ) . 'px' );

	// Pagination border.
	$pagination_border = Technologist_Sanitize::border( technologist_get_settings( 'pagenavigation_border' ) );
	$css['global'][ technologist_implode( $border_radius_class ) ][ $pagination_border['direction'] ] = $pagination_border['value'];

	// Pagination Alignment.
	$pagenavigation_align = technologist_get_settings( 'pagenavigation_alignment' );
	if ( 'left' === $pagenavigation_align ) :
		$css['global']['.pagination']['text-align'] = 'left';
	elseif ( 'right' === $pagenavigation_align ) :
		$css['global']['.pagination']['text-align'] = 'right';
	endif;

	// Load more Alignment.
	$load_more_align = technologist_get_settings( 'load_more_alignment' );
	if ( 'left' === $load_more_align ) :
		$css['global']['#load-posts']['text-align'] = 'left';
	elseif ( 'right' === $load_more_align ) :
		$css['global']['#load-posts']['text-align'] = 'right';
	elseif ( 'full' === $load_more_align ) :
		$css['global']['#load-posts a']['width'] = '100%';
	endif;

}

/**
 * Pages
 *
 * @param array $css Array of dynamic CSS.
 */
function technologist_pages( &$css ) {

	$page_classes = [
		'.page .article',
		'.error404 .article',
	];

	$css['global'][ technologist_implode( $page_classes ) ] = Technologist_Sanitize::background( technologist_get_settings( 'pages_background' ) );

	// Margin and Padding.
	technologist_merge_value( $css['global'][ technologist_implode( $page_classes ) ], Technologist_Sanitize::margin( technologist_get_settings( 'pages_margin' ) ) );
	technologist_merge_value( $css['global'][ technologist_implode( $page_classes ) ], Technologist_Sanitize::padding( technologist_get_settings( 'pages_padding' ) ) );

	// Border.
	$single_border = Technologist_Sanitize::border( technologist_get_settings( 'pages_border' ) );
	$css['global'][ technologist_implode( $page_classes ) ][ $single_border['direction'] ] = $single_border['value'];

	// Border Radius.
	$css['global'][ technologist_implode( $page_classes ) ]['border-radius'] = Technologist_Sanitize::size( technologist_get_settings( 'pages_border_radius' ) . 'px' );

}

/**
 * Single
 *
 * @param array $css Array of dynamic CSS.
 */
function technologist_single( &$css ) {

	// Single.
	$css['global']['.article .single_post'] = Technologist_Sanitize::background( technologist_get_settings( 'single_background' ) );

	// Category BG color.
	$css['global']['.single-full-header .post-info.top a']['background-color'] = Technologist_Sanitize::color( technologist_get_settings( 'single_categories_bg_color' ) );

	// Margin and Padding.
	technologist_merge_value( $css['global']['.single.single_post_wrap'], Technologist_Sanitize::margin( technologist_get_settings( 'mts_single_styling_margin' ) ) );
	technologist_merge_value( $css['global']['.article .single_post'], Technologist_Sanitize::padding( technologist_get_settings( 'mts_single_styling_padding' ) ) );

	// Single border.
	$single_border = Technologist_Sanitize::border( technologist_get_settings( 'single_styling_border' ) );
	$css['global']['.article .single_post'][ $single_border['direction'] ] = $single_border['value'];

	// Border Radius.
	$css['global']['.article .single_post']['border-radius'] = Technologist_Sanitize::size( technologist_get_settings( 'single_styling_border_radius' ) . 'px' );

	// Typography.
	technologist_map_css_selectors( $css['global'], Technologist_Sanitize::typography( technologist_get_settings( 'single_meta_info_font' ) ) );

	$single_meta_info_class = '.single-full-header .post-info > span:after';
	$single_meta_info_font  = technologist_get_settings( 'single_meta_info_font' );
	// bullet background.
	$css['global'][ $single_meta_info_class ]['background-color'] = Technologist_Sanitize::color( $single_meta_info_font['color'] );

	/**
	 * Breadcrumbs.
	 */
	// Background.
	technologist_merge_value( $css['global']['.breadcrumbs-wrapper'], Technologist_Sanitize::background( technologist_get_settings( 'breadcrumb_background' ) ) );

	// Margin and Padding.
	technologist_merge_value( $css['global']['.breadcrumbs-wrapper'], Technologist_Sanitize::margin( technologist_get_settings( 'breadcrumb_margin' ) ) );
	technologist_merge_value( $css['global']['.breadcrumbs-wrapper'], Technologist_Sanitize::padding( technologist_get_settings( 'breadcrumb_padding' ) ) );

	// Border Radius.
	$css['global']['.breadcrumbs-wrapper']['border-radius'] = Technologist_Sanitize::size( technologist_get_settings( 'breadcrumb_border_radius' ) . 'px' );

	// Typography.
	technologist_map_css_selectors( $css['global'], Technologist_Sanitize::typography( technologist_get_settings( 'breadcrumb_font' ) ) );

	/**
	 * Related Posts.
	 */
	$css['global']['.related-posts'] = Technologist_Sanitize::background( technologist_get_settings( 'related_posts_background' ) );

	// Title.
	$css['global']['.related-posts .related-posts-title .main-title']['background-color'] = Technologist_Sanitize::color( technologist_get_settings( 'related_post_title_bg' ) );
	technologist_merge_value( $css['global']['.related-posts .related-posts-title .main-title'], Technologist_Sanitize::padding( technologist_get_settings( 'related_post_title_padding' ) ) );

	// Title border.
	$title_border = Technologist_Sanitize::border( technologist_get_settings( 'related_post_title_border' ) );
	$css['global']['.related-posts .related-posts-title'][ $title_border['direction'] ] = $title_border['value'];

	$css['global']['.related-posts .post-info.top a']['background-color'] = Technologist_Sanitize::color( technologist_get_settings( 'related_posts_categories_bg' ) );

	// Typography.
	technologist_map_css_selectors( $css['global'], Technologist_Sanitize::typography( technologist_get_settings( 'related_post_font' ) ) );
	technologist_map_css_selectors( $css['global'], Technologist_Sanitize::typography( technologist_get_settings( 'related_posts_categories_font' ) ) );
	technologist_map_css_selectors( $css['global'], Technologist_Sanitize::typography( technologist_get_settings( 'related_posts_meta_font' ) ) );
	technologist_map_css_selectors( $css['global'], Technologist_Sanitize::typography( technologist_get_settings( 'related_posts_title_font' ) ) );
	technologist_map_css_selectors( $css['global'], Technologist_Sanitize::typography( technologist_get_settings( 'related_posts_excerpt_font' ) ) );

	// Margin and Padding.
	technologist_merge_value( $css['global']['.related-posts'], Technologist_Sanitize::margin( technologist_get_settings( 'related_posts_margin' ) ) );
	technologist_merge_value( $css['global']['.related-posts'], Technologist_Sanitize::padding( technologist_get_settings( 'related_posts_padding' ) ) );

	$related_posts_border = Technologist_Sanitize::border( technologist_get_settings( 'related_posts_border' ) );
	$css['global']['.related-posts'][ $related_posts_border['direction'] ] = $related_posts_border['value'];

	$related_meta_info_class = '.related-posts .latestPost .post-info > span:after';
	$related_posts_meta_font = technologist_get_settings( 'related_posts_meta_font' );

	// Related Meta Info.
	$css['global'][ $related_meta_info_class ]['background-color'] = Technologist_Sanitize::color( $related_posts_meta_font['color'] );

	// Related Posts articles.
	$css['global']['.related-posts article'] = Technologist_Sanitize::background( technologist_get_settings( 'related_article_background' ) );

	technologist_merge_value( $css['global']['.related-posts article'], Technologist_Sanitize::padding( technologist_get_settings( 'related_article_padding' ) ) );

	technologist_merge_value( $css['global']['.related-posts article .wrapper'], Technologist_Sanitize::padding( technologist_get_settings( 'related_article_text_padding' ) ) );

	// Border Radius.
	$css['global']['.related-posts #featured-thumbnail img']['border-radius'] = Technologist_Sanitize::size( technologist_get_settings( 'related_post_image_border_radius' ) . 'px' );

	/**
	 * Subscribe Box.
	 */
	$css['global']['.single-subscribe .widget.wp_subscribe'] = Technologist_Sanitize::background( technologist_get_settings( 'single_subscribe_background' ) );

	// Margin and Padding.
	technologist_merge_value( $css['global']['.single-subscribe .widget.wp_subscribe'], Technologist_Sanitize::margin( technologist_get_settings( 'single_subscribe_margin' ) ) );
	technologist_merge_value( $css['global']['.single-subscribe .widget.wp_subscribe'], Technologist_Sanitize::padding( technologist_get_settings( 'single_subscribe_padding' ) ) );

	$css['global']['.single-subscribe .widget.wp_subscribe']['border-radius'] = Technologist_Sanitize::size( technologist_get_settings( 'single_subscribe_border_radius' ) . 'px' );

	// Subscribe border.
	$subscribe_border = Technologist_Sanitize::border( technologist_get_settings( 'single_subscribe_border' ) );
	$css['global']['.single-subscribe .widget.wp_subscribe'][ $subscribe_border['direction'] ] = $subscribe_border['value'];

	// Subscribe Box Input fields.
	$subscribe_input_class = [
		'.single-subscribe #wp-subscribe input.email-field',
		'.single-subscribe #wp-subscribe input.name-field',
	];
	$css['global'][ technologist_implode( $subscribe_input_class ) ]['height'] = Technologist_Sanitize::size( technologist_get_settings( 'single_subscribe_input_height' ) . 'px' );

	$css['global']['.single-subscribe .widget #wp-subscribe input.submit']['height'] = Technologist_Sanitize::size( technologist_get_settings( 'single_subscribe_input_height' ) . 'px' );

	$css['global']['.single-subscribe .widget #wp-subscribe input.submit']['line-height'] = Technologist_Sanitize::size( technologist_get_settings( 'single_subscribe_input_height' ) . 'px' );

	$css['global'][ technologist_implode( $subscribe_input_class ) ]['border-radius'] = Technologist_Sanitize::size( technologist_get_settings( 'single_subscribe_input_border_radius' ) . 'px' );

	// Subscribe Box Input border.
	technologist_merge_value( $css['global'][ technologist_implode( $subscribe_input_class ) ], Technologist_Sanitize::border2( technologist_get_settings( 'single_subscribe_input_border' ) ) );

	// Subscribe Box Submit button.
	$css['global']['.single-subscribe .widget #wp-subscribe input.submit']['background']    = Technologist_Sanitize::color( technologist_get_settings( 'single_subscribe_submit_backgroud' ) );
	$css['global']['.single-subscribe .widget #wp-subscribe input.submit']['border-radius'] = Technologist_Sanitize::size( technologist_get_settings( 'single_subscribe_submit_border_radius' ) . 'px' );

	// Subscribe Box Submit border.
	$subscribe_box_submit_border = Technologist_Sanitize::border( technologist_get_settings( 'single_subscribe_submit_border' ) );
	$css['global']['.single-subscribe .widget #wp-subscribe input.submit'][ $subscribe_box_submit_border['direction'] ] = $subscribe_box_submit_border['value'];

	technologist_merge_value( $css['global']['.single-subscribe .widget #wp-subscribe input.submit'], Technologist_Sanitize::padding( technologist_get_settings( 'single_subscribe_submit_padding' ) ) );

	// Author Box.
	$css['global']['.postauthor'] = Technologist_Sanitize::background( technologist_get_settings( 'authorbox_background' ) );

	technologist_merge_value( $css['global']['.postauthor'], Technologist_Sanitize::margin( technologist_get_settings( 'authorbox_margin' ) ) );

	technologist_merge_value( $css['global']['.postauthor'], Technologist_Sanitize::padding( technologist_get_settings( 'authorbox_padding' ) ) );

	$css['global']['.postauthor']['border-radius'] = Technologist_Sanitize::size( technologist_get_settings( 'authorbox_border_radius' ) . 'px' );

	// Border.
	technologist_merge_value( $css['global']['.postauthor'], Technologist_Sanitize::border2( technologist_get_settings( 'authorbox_border' ) ) );

	// Author image.
	$image_margin = Technologist_Sanitize::margin( technologist_get_settings( 'single_author_image_margin' ) );

	technologist_merge_value( $css['global']['.postauthor img'], $image_margin );

	$css['global']['.postauthor img']['border-radius'] = Technologist_Sanitize::size( technologist_get_settings( 'single_author_image_border_radius' ) . 'px' );

	// Author content wrapper.
	$image_size = technologist_get_settings( 'author_image_size' );
	$css['global']['.postauthor .content-wrap']['width'] = 'calc( 100% - ( ' . $image_size . 'px + ' . $image_margin['margin-right'] . ' ) )';

	// Author Content Border.
	technologist_merge_value( $css['global']['.postauthor .content-wrap'], Technologist_Sanitize::border2( technologist_get_settings( 'authorbox_content_border' ) ) );

	// Single Page titles Styling.
	$titles_align = technologist_get_settings( 'single_title_alignment' );

	$titles_align_class = [
		'.comment-title',
		'#respond',
		'.related-posts-title',
	];
	$titles_class       = [
		'#respond h4',
		'.total-comments',
		'.related-posts h4',
	];

	$css['global'][ technologist_implode( $titles_class ) ] = Technologist_Sanitize::background( technologist_get_settings( 'single_title_background' ) );
	technologist_merge_value( $css['global'][ technologist_implode( $titles_class ) ], Technologist_Sanitize::padding( technologist_get_settings( 'single_title_padding' ) ) );
	// Single title border.
	$single_titles_border = Technologist_Sanitize::border( technologist_get_settings( 'single_title_border' ) );
	$css['global'][ technologist_implode( $titles_class ) ][ $single_titles_border['direction'] ] = $single_titles_border['value'];

	if ( 'left' === $titles_align ) :
		$css['global'][ technologist_implode( $titles_class ) ]['display'] = 'inline-block';
	elseif ( 'center' === $titles_align ) :
		$css['global'][ technologist_implode( $titles_align_class ) ]['text-align'] = 'center';
		$css['global'][ technologist_implode( $titles_class ) ]['display']          = 'inline-block';
	elseif ( 'right' === $titles_align ) :
		$css['global'][ technologist_implode( $titles_align_class ) ]['text-align'] = 'right';
		$css['global'][ technologist_implode( $titles_class ) ]['display']          = 'inline-block';
	endif;

	// Comments.
	// Margin and Padding.
	technologist_merge_value( $css['global']['#comments'], Technologist_Sanitize::margin( technologist_get_settings( 'comments_margin' ) ) );
	technologist_merge_value( $css['global']['#comments'], Technologist_Sanitize::padding( technologist_get_settings( 'comments_padding' ) ) );
	technologist_merge_value( $css['global']['#comments li'], Technologist_Sanitize::margin( technologist_get_settings( 'comments_list_margin' ) ) );
	technologist_merge_value( $css['global']['#comments li'], Technologist_Sanitize::padding( technologist_get_settings( 'comments_list_padding' ) ) );
	technologist_merge_value( $css['global']['#comments .avatar'], Technologist_Sanitize::margin( technologist_get_settings( 'comments_list_image_margin' ) ) );

	// Author Comment.
	technologist_merge_value( $css['global']['#comments li.bypostauthor'], Technologist_Sanitize::margin( technologist_get_settings( 'comments_list_author_margin' ) ) );
	technologist_merge_value( $css['global']['#comments li.bypostauthor'], Technologist_Sanitize::padding( technologist_get_settings( 'comments_list_author_padding' ) ) );
	$css['global']['#comments li.bypostauthor']['background-color'] = Technologist_Sanitize::color( technologist_get_settings( 'author_comment_bg' ) );

	// Comment list.
	// Border.
	$single_titles_border = Technologist_Sanitize::border( technologist_get_settings( 'comments_list_border' ) );
	$css['global']['#comments li'][ $single_titles_border['direction'] ] = $single_titles_border['value'];

	$css['global']['#comments ul.children']['border-top'] = $single_titles_border ['value'];

	$css['global']['#comments .avatar']['border-radius'] = Technologist_Sanitize::size( technologist_get_settings( 'comments_list_image_border_radius' ) . 'px' );

	// Typography.
	technologist_map_css_selectors( $css['global'], Technologist_Sanitize::typography( technologist_get_settings( 'comments_title_font' ) ) );
	technologist_map_css_selectors( $css['global'], Technologist_Sanitize::typography( technologist_get_settings( 'comments_meta_font' ) ) );
	technologist_map_css_selectors( $css['global'], Technologist_Sanitize::typography( technologist_get_settings( 'comments_text_font' ) ) );

}

/**
 * Footer logo and icons
 *
 * @param array $css Array of dynamic CSS.
 */
function technologist_footer_section( &$css ) {

	// Logo Typography.
	technologist_map_css_selectors( $css['global'], Technologist_Sanitize::typography( technologist_get_settings( 'footer_logo_font' ) ) );

	$footer_icons = technologist_get_settings( 'footer_social_icons' );

	// Footer icons.
	if ( $footer_icons && is_array( $footer_icons ) ) {

		foreach ( $footer_icons as $footer_icon ) {

			$css['global'][ '.footer-social-icons a.footer-' . $footer_icon['footer_icon'] ]['background-color'] = Technologist_Sanitize::color( $footer_icon['footer_icon_bgcolor'] );

			$css['global'][ '.footer-social-icons a.footer-' . $footer_icon['footer_icon'] . ':hover' ]['background-color'] = Technologist_Sanitize::color( $footer_icon['footer_icon_hover_bgcolor'] );

			$css['global'][ '.footer-social-icons a.footer-' . $footer_icon['footer_icon'] ]['color'] = Technologist_Sanitize::color( $footer_icon['footer_icon_color'] );

			$css['global'][ '.footer-social-icons a.footer-' . $footer_icon['footer_icon'] . ':hover' ]['color'] = Technologist_Sanitize::color( $footer_icon['footer_icon_hover_color'] );

			technologist_merge_value( $css['global'][ '.footer-social-icons a.footer-' . $footer_icon['footer_icon'] ], Technologist_Sanitize::margin( $footer_icon['footer_icon_margin'] ) );

			technologist_merge_value( $css['global'][ '.footer-social-icons a.footer-' . $footer_icon['footer_icon'] ], Technologist_Sanitize::padding( $footer_icon['footer_icon_padding'] ) );

			$css['global'][ '.footer-social-icons a.footer-' . $footer_icon['footer_icon'] ]['border-radius'] = Technologist_Sanitize::size( $footer_icon['footer_icon_border_radius'] . 'px' );

		}
	}

	// Margin and Padding.
	technologist_merge_value( $css['global']['.footer-section'], Technologist_Sanitize::margin( technologist_get_settings( 'footer_section_margin' ) ) );
	technologist_merge_value( $css['global']['.footer-section'], Technologist_Sanitize::padding( technologist_get_settings( 'footer_section_padding' ) ) );

}

/**
 * Footer
 *
 * @param array $css Array of dynamic CSS.
 */
function technologist_footer( &$css ) {

	// Footer.
	if ( technologist_get_settings( 'mts_top_footer' ) ) {
		technologist_merge_value( $css['global']['#site-footer'], Technologist_Sanitize::margin( technologist_get_settings( 'footer_margin' ) ) );
		technologist_merge_value( $css['global']['#site-footer .footer-widgets'], Technologist_Sanitize::padding( technologist_get_settings( 'footer_padding' ) ) );

		// Border.
		$copyrights_border = Technologist_Sanitize::border( technologist_get_settings( 'footer_border' ) );
		$css['global']['#site-footer'][ $copyrights_border['direction'] ] = $copyrights_border['value'];
	}

}

/**
 * Copyrights
 *
 * @param array $css Array of dynamic CSS.
 */
function technologist_copyrights( &$css ) {

	// Border.
	$copyrights_border = Technologist_Sanitize::border( technologist_get_settings( 'copyrights_border' ) );
	$css['global']['.copyrights .container'][ $copyrights_border['direction'] ] = $copyrights_border['value'];

	// Margin and Padding.
	technologist_merge_value( $css['global']['.copyrights'], Technologist_Sanitize::margin( technologist_get_settings( 'copyrights_margin' ) ) );
	technologist_merge_value( $css['global']['.copyrights .container'], Technologist_Sanitize::padding( technologist_get_settings( 'copyrights_padding' ) ) );

}

/**
 * Archive
 *
 * @param array $css Array of dynamic CSS.
 */
function technologist_archive_post( &$css ) {

	$archive_category = [
		'.archive .post-info.top a',
		'.search .post-info.top a',
	];
	$archive_thumb = [
		'.archive .latestPost #featured-thumbnail',
		'.search .latestPost #featured-thumbnail',
	];
	$archive_meta_class = [
		'.archive .post-info > span:after',
		'.search .post-info > span:after',
	];

	// Categories BG color.
	$css['global'][ technologist_implode( $archive_category ) ]['background-color'] = Technologist_Sanitize::color( technologist_get_settings( 'archive_categories_bg' ) );

	// Thumbnail Border-radius.
	$css['global'][ technologist_implode( $archive_thumb ) ]['border-radius'] = Technologist_Sanitize::size( technologist_get_settings( 'archive_image_border_radius' ) . 'px' );

	// Typography.
	technologist_map_css_selectors( $css['global'], Technologist_Sanitize::typography( technologist_get_settings( 'archive_categories_font' ) ) );
	technologist_map_css_selectors( $css['global'], Technologist_Sanitize::typography( technologist_get_settings( 'archive_post_title_font' ) ) );
	technologist_map_css_selectors( $css['global'], Technologist_Sanitize::typography( technologist_get_settings( 'archive_meta_info_font' ) ) );
	technologist_map_css_selectors( $css['global'], Technologist_Sanitize::typography( technologist_get_settings( 'archive_post_excerpt_font' ) ) );

	$archive_posts_meta_font = technologist_get_settings( 'archive_meta_info_font' );
	// divider background.
	$css['global'][ technologist_implode( $archive_meta_class ) ]['background-color'] = Technologist_Sanitize::color( $archive_posts_meta_font['color'] );

}

/**
 * Misc
 *
 * @param array $css Array of dynamic CSS.
 */
function technologist_misc_css( &$css ) {

	// Show Logo.
	if ( ! technologist_get_settings( 'hide_logo' ) ) {
		$css['global']['.logo-wrap']['display'] = 'none';
	}

	if ( technologist_get_settings( 'logo_styling' ) ) {
		$css['global']['header .text-logo']['background-color'] = Technologist_Sanitize::color( technologist_get_settings( 'logo_bg_color' ) );
		technologist_merge_value( $css['global']['header .text-logo a'], Technologist_Sanitize::padding( technologist_get_settings( 'logo_padding' ) ) );
	}

	// Border.
	$top_button_border = Technologist_Sanitize::border( technologist_get_settings( 'top_button_border' ) );
	$css['global']['#move-to-top'][ $top_button_border['direction'] ] = $top_button_border['value'];

	// Padding and Position.
	technologist_merge_value( $css['global']['#move-to-top'], Technologist_Sanitize::padding( technologist_get_settings( 'top_button_padding' ) ) );

	$top_button_position = technologist_get_settings( 'top_button_position' );
	if ( $top_button_position && is_array( $top_button_position ) ) {
		foreach ( $top_button_position as $key => $position ) {
			$css['global']['#move-to-top'][ $key ] = $position;
		}
	}

	// Border-radius.
	$css['global']['#move-to-top']['border-radius'] = Technologist_Sanitize::size( technologist_get_settings( 'top_button_border_radius' ) . 'px' );

	// Colors.
	$css['global']['#move-to-top']['background-color'] = Technologist_Sanitize::color( technologist_get_settings( 'top_button_background' ) );

	$css['global']['a#move-to-top']['color'] = Technologist_Sanitize::color( technologist_get_settings( 'top_button_color' ) );

	$css['global']['a#move-to-top:hover']['color'] = Technologist_Sanitize::color( technologist_get_settings( 'top_button_color_hover' ) );

	$css['global']['#move-to-top:hover']['background-color'] = Technologist_Sanitize::color( technologist_get_settings( 'top_button_background_hover' ) );

	technologist_map_css_selectors( $css['global'], Technologist_Sanitize::typography( technologist_get_settings( 'top_text_font' ) ) );

	// Full width Related Posts.
	if ( 'full' === technologist_get_settings( 'related_posts_position' ) ) {
		$css['global']['.single-post .article']['margin-bottom'] = '0px';
	}

}

/**
 * WooCommerce
 *
 * @param array $css Array of dynamic CSS.
 */
function technologist_woo( &$css ) {

	$woo_classes        = [
		'.woocommerce nav.woocommerce-pagination ul li a',
		'.woocommerce-page nav.woocommerce-pagination ul li a',
	];
	$woo_hover_classes  = [
		'.woocommerce nav.woocommerce-pagination ul li a:hover',
		'.woocommerce nav.woocommerce-pagination ul li a:focus',
		'.woocommerce-page nav.woocommerce-pagination ul li a:hover',
		'.woocommerce-page nav.woocommerce-pagination ul li a:focus',
	];
	$woo_active_classes = [
		'.woocommerce nav.woocommerce-pagination ul li span.current',
		'.woocommerce-page nav.woocommerce-pagination ul li span.current',
	];

	$css['global'][ technologist_implode( $woo_classes ) ] = Technologist_Sanitize::background( technologist_get_settings( 'mts_pagenavigation_bgcolor' ) );

	$css['global'][ technologist_implode( $woo_hover_classes ) ] = Technologist_Sanitize::background( technologist_get_settings( 'mts_pagenavigation_hover_bgcolor' ) );

	$css['global'][ technologist_implode( $woo_active_classes ) ] = Technologist_Sanitize::background( technologist_get_settings( 'mts_pagenavigation_active_bgcolor' ) );

	// Typography.
	technologist_map_css_selectors( $css['global'], Technologist_Sanitize::typography( technologist_get_settings( 'woo_single_title_font' ) ) );
	technologist_map_css_selectors( $css['global'], Technologist_Sanitize::typography( technologist_get_settings( 'woo_single_text_font' ) ) );

	// Border radius.
	$css['global'][ technologist_implode( $woo_classes ) ]['border-radius'] = Technologist_Sanitize::size( technologist_get_settings( 'mts_pagenavigation_border_radius' ) . 'px' );

}
