<?php
/**
 * Template functions that the framework or themes may use.
 *
 * @package Technologist
 */

if ( ! function_exists( 'technologist_logo' ) ) {
	/**
	 * Site Logo
	 *
	 * @param array  $args args for overriding.
	 * @param string $loc for logo location.
	 * @return void
	 */
	function technologist_logo( $args = [], $loc = 'mts' ) {

		$technologist_logo = wp_get_attachment_url( technologist_get_settings( $loc . '_logo' ) );

		$h_tag     = 'h2';
		$logo_type = 'text-logo';

		if ( is_home() ) {
			$h_tag = 'h1';
		}

		if ( 'footer' === $loc ) {
			$h_tag = 'div';
		}

		if ( ! empty( $technologist_logo ) ) {
			$logo_type = 'image-logo';
		}

		$defaults = [
			'logo'   => $technologist_logo,
			'url'    => esc_url( home_url() ),
			'title'  => get_bloginfo( 'name' ),
			'before' => '<' . $h_tag . ' id="logo" class="' . $logo_type . ' clearfix" itemprop="headline">',
			'after'  => '</' . $h_tag . '>',
		];

		$args = wp_parse_args( $args, $defaults );

		$output = $args['logo'] ? sprintf( '<img src="' . $args['logo'] . '" alt="' . esc_attr( $args['title'] ) . '">' ) : $args['title'];
		$output = sprintf( '<a href="%1$s">%2$s</a>', $args['url'], $output );

		echo wp_kses_post( $args['before'] ) . $output . wp_kses_post( $args['after'] );
	}
}

if ( ! function_exists( 'technologist_single_featured_image_effect' ) ) {
	/**
	 * Single Post Header Layout type (Parallax or Zoomout) *
	 */
	function technologist_single_featured_image_effect() {

		$header_animation = technologist_get_post_header_effect();

		if ( has_post_thumbnail() ) {
			if ( 'parallax' === $header_animation ) {
				echo '<div id="parallax" style="background-image: url(' . get_the_post_thumbnail_url( get_the_ID(), 'technologist-single-featured' ) . ');"></div>';
			} elseif ( 'zoomout' === $header_animation ) {
				echo '<div id="zoom-out-effect"><div id="zoom-out-bg" style="background-image: url(' . get_the_post_thumbnail_url( get_the_ID(), 'full' ) . ');"></div></div>';
			}
		}

	}
}

if ( ! function_exists( 'technologist_post_tags' ) ) {
	/**
	 * Display technologist-compliant the_tags()
	 *
	 * @param string $before before tag.
	 * @param string $sep tags separator.
	 * @param string $after after tag.
	 */
	function technologist_post_tags( $before = '', $sep = ', ', $after = '</div>' ) {
		if ( empty( $before ) ) {
			$before = '<div class="tags">' . esc_html__( 'Tags', 'technologist' );
		}
		$tags = get_the_tags();
		if ( empty( $tags ) || is_wp_error( $tags ) ) {
			return;
		}
		$tag_links = [];
		foreach ( $tags as $tag ) {
			$link        = get_tag_link( $tag->term_id );
			$tag_links[] = '<a href="' . esc_url( $link ) . '" rel="tag">' . $tag->name . '</a>';
		}
		echo $before . join( $sep, $tag_links ) . $after; // phpcs:ignore
	}
}

if ( ! function_exists( 'technologist_categorized_blog' ) ) {
	/**
	 * Returns true if a blog has more than 1 category.
	 *
	 * @return bool
	 */
	function technologist_categorized_blog() {
		$category_count = get_transient( 'technologist_categories' );

		if ( false === $category_count ) {
			// Create an array of all the categories that are attached to posts.
			$categories = get_categories( [
				'fields'     => 'ids',
				'hide_empty' => 1,
				// We only need to know if there is more than one category.
				'number'     => 2,
			] );

			// Count the number of categories that are attached to the posts.
			$category_count = count( $categories );

			set_transient( 'technologist_categories', $category_count );
		}

		return $category_count > 1;
	}
}

if ( ! function_exists( 'technologist_section_title' ) ) {
	/**
	 * Template for displaying section title
	 *
	 * @param string $id option id of section.
	 * @param string $class section class.
	 *
	 * @return void
	 */
	function technologist_section_title( $id, $class = 'main-title' ) {

		$title = technologist_get_settings( $id );

		if ( $title['heading'] && $title['tag'] ) {
			printf(
				'<%1$s class="%2$s">%3$s</%1$s>',
				esc_html( $title['tag'] ),
				esc_html( $class ),
				esc_html( $title['heading'] )
			);
		}

	}
}

if ( ! function_exists( 'technologist_post_title' ) ) {
	/**
	 * Template for displaying posts title
	 *
	 * @param string $section for page or section name.
	 *
	 * @return void
	 */
	function technologist_post_title( $section = '' ) {

		if ( 'single' === $section ) :
			the_title( '<h1 class="title single-title entry-title">', '</h1>' );
		else :
			the_title( sprintf( '<h2 class="title front-view-title"><a href="%s" title="%s">', esc_url( get_permalink() ), get_the_title() ), '</a></h2>' );
		endif;

	}
}

if ( ! function_exists( 'technologist_thumb_size' ) ) {
	/**
	 * Get thumb size according to section|layout
	 *
	 * @param string $section section|layout.
	 * @param int    $count post count.
	 *
	 * @return string $size thumb-size.
	 */
	function technologist_thumb_size( $section = 'layout-default', $count = null ) {

		$default_thumb = wp_is_mobile() ? 'technologist-related' : 'technologist-featured';

		$thumbs = [
			'layout-1' => 1 === $count % 2 ? 'technologist-layout-1' : 'technologist-layout-1-small',
			'layout-2' => 'technologist-layout-2',
			'layout-3' => 1 === $count ? 'technologist-layout-3' : 'technologist-layout-3-small',
			'related'  => 'technologist-related',
		];

		if ( wp_is_mobile() ) {
			$thumbs['layout-2'] = 'technologist-related';
		}
		$size = isset( $thumbs[ $section ] ) ? $thumbs[ $section ] : $default_thumb;

		return $size;

	}
}

if ( ! function_exists( 'technologist_wp_review' ) ) {
	/**
	 * Get review when WP Review enable
	 */
	function technologist_wp_review() {
		if ( function_exists( 'wp_review_show_total' ) ) {
			wp_review_show_total( true, 'latestPost-review-wrapper' );
		}
	}
}

if ( ! function_exists( 'technologist_post_formate_icon' ) ) {
	/**
	 * Get post icon according to post formate
	 *
	 * @return svg icon
	 */
	function technologist_post_formate_icon() {

		if ( ! has_post_format() || '' === get_post_format() ) {
			return;
		}

		echo '<div class="post-icon">';

		if ( has_post_format( 'video' ) ) {
			echo Technologist_Images::get_svg( 'video', 24, false );  // phpcs:ignore
		}
		if ( has_post_format( 'audio' ) ) {
			echo Technologist_Images::get_svg( 'audio', 24, false );  // phpcs:ignore
		}

		echo '</div>';

	}
}

if ( ! function_exists( 'technologist_post_thumbnail' ) ) {
	/**
	 * Displays post thumbnail.
	 *
	 * @param string $section section|layout.
	 * @param int    $count post count.
	 *
	 * @return void
	 */
	function technologist_post_thumbnail( $section = 'layout-default', $count = null ) {

		$size = technologist_thumb_size( $section, $count );
		$attr = [
			'title' => get_the_title(),
			'alt'   => get_the_title(),
		];
		?>

		<a href="<?php echo esc_url( get_the_permalink() ); ?>" title="<?php the_title_attribute(); ?>" id="featured-thumbnail" class="post-image post-image-left <?php echo esc_html( $size ); ?>">

			<?php technologist_post_formate_icon(); ?>

			<figure class="featured-thumbnail">
				<?php
				if ( has_post_thumbnail() ) {
					the_post_thumbnail( $size, $attr );
				} else {
					echo '<img src="' . get_template_directory_uri() . '/images/nothumb-' . $size . '.png" alt="' . __( 'No Preview', 'technologist' ) . '"  class="wp-post-image" />'; // phpcs:ignore
				}
				?>
			</figure>

			<?php technologist_wp_review(); ?>

		</a>

		<?php
	}
}

if ( ! function_exists( 'technologist_post_content' ) ) {
	/**
	 * Get post content.
	 *
	 * @param boolean $is_enable check if content is enable to show.
	 *
	 * @param int     $length excerpt lenght.
	 *
	 * @return void
	 */
	function technologist_post_content( $is_enable = true, $length = 55 ) {

		if ( ! $is_enable ) {
			return;
		}
		?>

		<div class="front-view-content">
			<?php echo get_technologist_excerpt( $length ); // phpcs:ignore ?>
		</div>

		<?php
	}
}

if ( ! function_exists( 'technologist_the_post_meta' ) ) {
	/**
	 * Display the post info block.
	 *
	 * @param string $section for page or section name.
	 * @param string $location top|bottom.
	 * @param string $unique_id unique id for dynamic blog layouts.
	 */
	function technologist_the_post_meta( $section = 'blog', $location = 'bottom', $unique_id = '' ) {

		$enabled_metas = technologist_get_settings( $section . '_meta_info' . $unique_id );

		if ( ! empty( $enabled_metas ) ) {

			if (
				'top' === $location &&
				isset( $enabled_metas['category'] )
				) {
				?>

				<div class="post-info top">
					<?php
					if ( isset( $enabled_metas['category'] ) ) :
						echo '<span class="thecategory">' . technologist_get_the_category( '' ) . '</span>'; // phpcs:ignore
					endif;
					?>
				</div>

				<?php
			} elseif (
				'bottom' === $location &&
				( isset( $enabled_metas['author'] ) || isset( $enabled_metas['date'] ) || isset( $enabled_metas['comment'] ) )
				) {
				?>

				<div class="post-info bottom">
					<?php
					if ( isset( $enabled_metas['author'] ) ) :
						echo '<span class="theauthor">' . get_the_author_posts_link() . '</span>'; // phpcs:ignore
					endif;
					if ( isset( $enabled_metas['date'] ) ) :
						echo '<span class="thetime date updated">' . get_the_time( get_option( 'date_format' ) ) . '</span>'; // phpcs:ignore
					endif;
					if ( isset( $enabled_metas['comment'] ) ) :
						printf( '<span class="thecomment"><a href="%s" itemprop="interactionCount">%s</a></span>', esc_url( get_comments_link() ), get_comments_number_text() ); // phpcs:ignore
					endif;
					?>
				</div>

				<?php
			}
		}
	}
}

if ( ! function_exists( 'technologist_get_the_category' ) ) {
	/**
	 * Display technologist-compliant the_category()
	 *
	 * @param string $separator for category separator.
	 */
	function technologist_get_the_category( $separator = ', ' ) {
		$categories = get_the_category();

		if ( empty( $categories ) ) {
			return;
		}

		global $wp_rewrite;

		$links = [];
		$rel   = ( is_object( $wp_rewrite ) && $wp_rewrite->using_permalinks() ) ? 'rel="category tag"' : 'rel="category"';

		foreach ( $categories as $category ) {

			$links[] = sprintf(
				'<a href="%1$s" title="%2$s" %3$s>%4$s</a>',
				esc_url( get_category_link( $category->term_id ) ),
				// translators: category name.
				sprintf( esc_html__( 'View all posts in %s', 'technologist' ), esc_attr( $category->name ) ),
				$rel,
				esc_html( $category->name )
			);
		}

		return join( $separator, $links );
	}
}

if ( ! function_exists( 'technologist_pagination' ) ) {
	/**
	 * Display the pagination.
	 *
	 * @param string $nav_type pagination type - number, load more, ajax etc...
	 */
	function technologist_pagination( $nav_type = '' ) {

		if ( 1 === $GLOBALS['wp_query']->max_num_pages ) {
			return;
		}

		if ( 1 === $nav_type ) { // Numeric pagination.
			the_posts_pagination( [
				'mid_size'  => 3,
				'prev_text' => '<',
				'next_text' => '>',
			] );
		} else { // traditional or ajax pagination.
			?>
			<div class="pagination pagination-previous-next">
				<ul>
					<li class="nav-previous"><?php next_posts_link( esc_html__( 'Previous', 'technologist' ) ); ?></li>
					<li class="nav-next"><?php previous_posts_link( esc_html__( 'Next', 'technologist' ) ); ?></li>
				</ul>
			</div>
			<?php
		}
	}
}

/**
 * Display social icons.
 *
 * @param array  $data social icons array from options panel.
 * @param string $loc location of icons.
 * @param boolen $echo echo or return.
 * @return html
 */
function technologist_social_icons( $data = [], $loc = 'header', $echo = false ) {

	if ( empty( $data ) || ! is_array( $data ) ) {
		return;
	}

	$out = '<div class="' . $loc . '-social-icons">';
	foreach ( $data as $item ) {
		$out .= sprintf(
			'<a href="%1$s" title="%2$s" class="%4$s-%3$s" target="_blank"><span class="fa fa-%3$s"></span></a>',
			$item[ $loc . '_icon_link' ],
			$item[ $loc . '_icon_title' ],
			$item[ $loc . '_icon' ],
			$loc
		);
	}

	$out .= '</div>';

	if ( $echo ) {
		echo $out; // phpcs:ignore
	} else {
		return $out;
	}
}

if ( ! function_exists( 'technologist_get_featured_image' ) ) {
	/**
	 * Create and show column for featured image in the post list of admin page
	 *
	 * @param num $post_id post id.
	 * @return string url
	 */
	function technologist_get_featured_image( $post_id ) {
		if ( $post_thumbnail_id = get_post_thumbnail_id( $post_id ) ) { // @codingStandardsIgnoreLine
			$post_thumbnail_img = wp_get_attachment_image_src( $post_thumbnail_id, 'technologist-widgetfull' );
			return $post_thumbnail_img[0];
		}
	}
}

if ( ! function_exists( 'technologist_columns_head' ) ) {
	/**
	 * Adds a `Featured Image` column header in the Post list of admin page
	 *
	 * @param array $defaults default array.
	 * @return array
	 */
	function technologist_columns_head( $defaults ) {
		if ( 'post' === get_post_type() ) {
			$defaults['featured_image'] = __( 'Featured Image', 'technologist' );
		}

		return $defaults;
	}
}
add_filter( 'manage_posts_columns', 'technologist_columns_head' );

if ( ! function_exists( 'technologist_columns_content' ) ) {
	/**
	 * Adds a `Featured Image` column row value in the Post list of admin page
	 *
	 * @param string $column_name The name of the column to display.
	 * @param int    $post_id The ID of the current post.
	 */
	function technologist_columns_content( $column_name, $post_id ) {
		if ( 'featured_image' === $column_name ) {
			if ( $post_featured_image = technologist_get_featured_image( $post_id ) ) { // @codingStandardsIgnoreLine
				echo '<img width="150" height="100" src="' . esc_url( $post_featured_image ) . '" />';
			}
		}
	}
}
add_action( 'manage_posts_custom_column', 'technologist_columns_content', 10, 2 );

if ( ! function_exists( 'technologist_footer_widget_columns' ) ) {
	/**
	 * Footer Widget Columns
	 *
	 * @return string
	 */
	function technologist_footer_widget_columns() {

		$footer_columns = intval( technologist_get_settings( 'mts_top_footer_num' ) );

		if ( ! $footer_columns ) {
			return;
		}
		?>

			<div class="footer-widgets first-footer-widgets widgets-num-<?php echo esc_attr( $footer_columns ); ?>">
				<div class="container">
					<?php
					for ( $i = 1; $i <= $footer_columns; $i++ ) :

						$class = '';
						if ( $i === $footer_columns ) {
							$class = ' last';
						} elseif ( 1 === $i ) {
							$class = ' first';
						}
						?>
						<div class="f-widget f-widget-<?php echo esc_attr( $i ) . esc_attr( $class ); ?>">
							<?php dynamic_sidebar( 'footer-top-' . $i ); ?>
						</div>
					<?php endfor; ?>
				</div>
			</div><!--.first-footer-widgets-->

		<?php
	}
}

if ( ! function_exists( 'technologist_footer_copyrights' ) ) {
	/**
	 * Copyrights section
	 */
	function technologist_footer_copyrights() {
		$content = technologist_get_settings( 'mts_copyrights' );

		$copyright_text = '<a href=" ' . esc_url( trailingslashit( home_url() ) ) . '" title=" ' . get_bloginfo( 'description' ) . '">' . get_bloginfo( 'name' ) . '</a> ' . __( 'Copyright', 'technologist' ) . ' &copy; ' . date( 'Y' ) . '.';
		?>
		<div class="copyrights">
			<div class="container"> 

				<div class="row" id="copyright-note">
					<span><?php echo $copyright_text; ?></span>
					<div class="to-top"><?php echo $content; ?></div>
				</div>

				<?php get_template_part( 'template-parts/footer/footer', 'nav' ); ?>

			</div>
		</div>
		<?php
	}
}

/**
 * Technologist display comments
 */
function technologist_display_comments() {
	// If comments are open or we have at least one comment, load up the comment template.
	if ( comments_open() || 0 !== intval( get_comments_number() ) ) :
		comments_template();
	endif;
}

if ( ! function_exists( 'technologist_comments' ) ) {
	/**
	 * Custom comments template.
	 *
	 * @param array $comment  get comment.
	 * @param array $args
	 * @param int   $depth    child depth.
	 */
	function technologist_comments( $comment, $args, $depth ) {
		$image_size = technologist_get_settings( 'comments_list_image_size' );
		?>
			<li <?php comment_class(); ?> id="li-comment-<?php comment_ID(); ?>">
				<?php
				switch ( $comment->comment_type ) :
					case 'pingback':
					case 'trackback':
						?>
							<div id="comment-<?php comment_ID(); ?>">
								<div class="comment-author vcard">
									Pingback: <?php comment_author_link(); ?>
									<?php if ( ! empty( technologist_get_settings( 'mts_comment_date' ) ) ) { ?>
										<div class="ago"><?php comment_date( get_option( 'date_format' ) ); ?></div>
									<?php } ?>
									<span class="comment-meta">
										<?php edit_comment_link( __( '( Edit )', 'technologist' ), '  ', '' ); ?>
									</span>
								</div>
								<?php if ( '0' === $comment->comment_approved ) : ?>
									<em><?php esc_html_e( 'Your comment is awaiting moderation.', 'technologist' ); ?></em>
									<br />
								<?php endif; ?>
							</div>
						<?php
						break;

					default:
						?>
							<div id="comment-<?php comment_ID(); ?>" itemscope itemtype="http://schema.org/UserComments">
								<div class="comment-author vcard">
									<?php echo get_avatar( $comment->comment_author_email, $image_size ); ?>
									<?php printf( '<span class="fn" itemprop="creator" itemscope itemtype="http://schema.org/Person"><span itemprop="name">%s</span></span>', get_comment_author_link() ); ?>
									<span class="comment-meta">
										<?php if ( ! empty( technologist_get_settings( 'mts_comment_date' ) ) ) { ?>
											<div class="ago"><?php comment_date( get_option( 'date_format' ) ); ?></div>
										<?php } ?>
										<?php edit_comment_link( __( '( Edit )', 'technologist' ), '  ', '' ); ?>
									</span>
									<div class="reply">
										<?php
										comment_reply_link( array_merge( $args, [
											'reply_text' => __( 'Reply', 'technologist' ),
											'depth'      => $depth,
											'max_depth'  => $args['max_depth'],
										] ) );
										?>
									</div>
								</div>
								<?php if ( '0' === $comment->comment_approved ) : ?>
									<em><?php esc_html_e( 'Your comment is awaiting moderation.', 'technologist' ); ?></em>
									<br />
								<?php endif; ?>
								<div class="commentmetadata">
									<div class="commenttext" itemprop="commentText">
										<?php comment_text(); ?>
									</div>
								</div>

							</div>
						<?php
						break;
				endswitch;
				?>
		<!-- WP adds </li> -->
		<?php
	}
}

/**
 * Return "Read More" HTML with a link.
 */
if ( ! function_exists( 'get_technologist_readmore' ) ) {
	/**
	 * Return "Read More" HTML with a link.
	 *
	 * @param string  $text read more custom text.
	 *
	 * @param boolean $icon true|false.
	 */
	function get_technologist_readmore( $text = 'Read the story', $icon = false ) {

		if ( $icon ) {
			$icon = '<i class="fa fa-angle-right"></i>';
		} else {
			$icon = '';
		}

		$output  = '<div class="readMore">';
		$output .= '<a href="' . get_the_permalink() . '">' . __( $text, 'technologist' ) . $icon . '</a>';
		$output .= '</div>';

		return $output;
	}
}

if ( ! function_exists( 'get_itemprop_3' ) ) {
	/**
	 * Last item in the breadcrumbs
	 */
	function get_itemprop_3( $title = '', $position = '2' ) {
		echo '<div itemprop="itemListElement" itemscope itemtype="https://schema.org/ListItem">';
		echo '<span itemprop="name">' . $title . '</span>';
		echo '<meta itemprop="position" content="' . $position . '" />';
		echo '</div>';
	}
}
if ( ! function_exists( 'technologist_breadcrumbs' ) ) {
	/**
	 * Display the breadcrumbs.
	 */
	function technologist_breadcrumbs() {

		if ( function_exists( 'rank_math_the_breadcrumbs' ) && RankMath\Helper::get_settings( 'general.breadcrumbs' ) ) {
			rank_math_the_breadcrumbs();
			return;
		}
		$separator = '<div class="separator"><i class="fa fa-angle-right"></i></div>';
		echo '<div class="breadcrumb" itemscope itemtype="https://schema.org/BreadcrumbList">';
		echo '<div itemprop="itemListElement" itemscope
	      itemtype="https://schema.org/ListItem" class="root"><a href="';
		echo esc_url( home_url() );
		echo '" itemprop="item"><span itemprop="name">' . esc_html__( 'Home', 'technologist' );
		echo '</span><meta itemprop="position" content="1" /></a></div>' . $separator;
		if ( is_single() ) {
			$categories = get_the_category();
			if ( $categories ) {
				$level         = 0;
				$hierarchy_arr = array();
				foreach ( $categories as $cat ) {
					$anc       = get_ancestors( $cat->term_id, 'category' );
					$count_anc = count( $anc );
					if ( 0 < $count_anc && $level < $count_anc ) {
						$level         = $count_anc;
						$hierarchy_arr = array_reverse( $anc );
						array_push( $hierarchy_arr, $cat->term_id );
					}
				}
				if ( empty( $hierarchy_arr ) ) {
					$category = $categories[0];
					echo '<div itemprop="itemListElement" itemscope
				      itemtype="https://schema.org/ListItem"><a href="' . esc_url( get_category_link( $category->term_id ) ) . '" itemprop="item"><span itemprop="name">' . esc_html( $category->name ) . '</span><meta itemprop="position" content="2" /></a></div>' . $separator;
				} else {
					foreach ( $hierarchy_arr as $cat_id ) {
						$category = get_term_by( 'id', $cat_id, 'category' );
						echo '<div itemprop="itemListElement" itemscope
					      itemtype="https://schema.org/ListItem"><a href="' . esc_url( get_category_link( $category->term_id ) ) . '" itemprop="item"><span itemprop="name">' . esc_html( $category->name ) . '</span><meta itemprop="position" content="2" /></a></div>' . $separator;
					}
				}
				get_itemprop_3( get_the_title(), '3' );
			} else {
				get_itemprop_3( get_the_title() );
			}
		} elseif ( is_page() ) {
			$parent_id = wp_get_post_parent_id( get_the_ID() );
			if ( $parent_id ) {
				$breadcrumbs = array();
				while ( $parent_id ) {
					$page          = get_page( $parent_id );
					$breadcrumbs[] = '<div itemprop="itemListElement" itemscope
				      itemtype="https://schema.org/ListItem"><a href="' . esc_url( get_permalink( $page->ID ) ) . '" itemprop="item"><span itemprop="name">' . esc_html( get_the_title( $page->ID ) ) . '</span><meta itemprop="position" content="2" /></a></div>' . $separator;

					$parent_id = $page->post_parent;
				}
				$breadcrumbs = array_reverse( $breadcrumbs );
				foreach ( $breadcrumbs as $crumb ) {
					echo $crumb;
				}
				get_itemprop_3( get_the_title(), 3 );
			} else {
				get_itemprop_3( get_the_title() );
			}
		} elseif ( is_category() ) {
			global $wp_query;
			$cat_obj       = $wp_query->get_queried_object();
			$this_cat_id   = $cat_obj->term_id;
			$hierarchy_arr = get_ancestors( $this_cat_id, 'category' );
			if ( $hierarchy_arr ) {
				$hierarchy_arr = array_reverse( $hierarchy_arr );
				foreach ( $hierarchy_arr as $cat_id ) {
					$category = get_term_by( 'id', $cat_id, 'category' );
					echo '<div itemprop="itemListElement" itemscope
				      itemtype="https://schema.org/ListItem"><a href="' . esc_url( get_category_link( $category->term_id ) ) . '" itemprop="item"><span itemprop="name">' . esc_html( $category->name ) . '</span><meta itemprop="position" content="2" /></a></div>' . $separator;
				}
			}
			get_itemprop_3( single_cat_title( '', false ) );
		} elseif ( is_author() ) {
			if ( get_query_var( 'author_name' ) ) :
				$curauth = get_user_by( 'slug', get_query_var( 'author_name' ) );
			else :
				$curauth = get_userdata( get_query_var( 'author' ) );
			endif;
			get_itemprop_3( esc_html( $curauth->nickname ) );
		} elseif ( is_search() ) {
			get_itemprop_3( get_search_query() );
		} elseif ( is_tag() ) {
			get_itemprop_3( single_tag_title( '', false ) );
		}
		echo '</div>';
	}
}

if ( ! empty( technologist_get_settings( 'mts_feedburner' ) ) ) {
	/**
	 * Redirect feed to FeedBurner if a FeedBurner URL has been set.
	 */
	function technologist_rss_feed_redirect() {
		global $feed;
		$new_feed = technologist_get_settings( 'mts_feedburner' );
		if ( ! is_feed() ) {
			return;
		}
		if ( preg_match( '/feedburner/i', $_SERVER['HTTP_USER_AGENT'] ) ) {
			return;
		}
		if ( 'comments-rss2' != $feed ) {
			if ( function_exists( 'status_header' ) ) status_header( 302 );
			header( "Location:" . $new_feed );
			header( "HTTP/1.1 302 Temporary Redirect" );
			exit();
		}
	}
	add_action( 'template_redirect', 'technologist_rss_feed_redirect' );
}

if ( ! function_exists( 'single_related_post' ) ) {
	/**
	 * Single Related Post structure
	 *
	 * @param string $layout Post layout.
	 */
	function single_related_post( $layout ) {

		$is_excerpt_on  = technologist_get_settings( 'related_show_excerpt' );
		$excerpt_length = technologist_get_settings( 'related_excerpt_length' );

		?>
		<article class="latestPost excerpt">

			<?php
			if ( 'rpost-3' !== $layout && 'rpost-5' !== $layout ) {
				technologist_post_thumbnail( 'related' );
			}
			?>

			<div class="wrapper">

				<header>
					<?php

					technologist_the_post_meta( 'related', 'top' );

					technologist_post_title();

					technologist_the_post_meta( 'related', 'bottom' );

					?>
				</header>

				<?php technologist_post_content( $is_excerpt_on, $excerpt_length ); ?>

			</div>

		</article><!--.post.excerpt-->
		<?php

	}
}

if ( ! function_exists( 'technologist_related_posts' ) ) {
	/**
	 * Display the related posts.
	 */
	function technologist_related_posts() {

		if ( empty( technologist_get_settings( 'mts_single_post_layout' )['enabled']['related'] ) ) {
			return;
		}

		// Defaults.
		$post_id      = get_the_ID();
		$tag_ids      = [];
		$category_ids = [];
		$post_layout  = 'default';
		$post_num     = 4;
		$position     = 'full';
		$main_classes = '';
		$count        = 0;

		$taxonomy       = technologist_get_settings( 'mts_related_posts_taxonomy' );
		$empty_taxonomy = false;

		$post_layout = technologist_get_settings( 'related_posts_layouts' );
		$post_num    = technologist_get_settings( 'mts_related_postsnum' );

		$position = technologist_get_settings( 'related_posts_position' );
		$grid     = 'default' === $post_layout && 'full' === $position ? ' ' . technologist_get_settings( 'related_posts_grid' ) : '';

		$main_classes = 'related-posts ' . $post_layout . $grid . ' position-' . $position;

		$args = [
			'post__not_in'        => [ $post_id ],
			'posts_per_page'      => $post_num,
			'ignore_sticky_posts' => 1,
			'orderby'             => 'rand',
		];

		// Related posts based on tags.
		if ( 'tags' === $taxonomy ) {

			$tags = get_the_tags( $post_id );

			if ( $tags ) {

				foreach ( $tags as $tag ) {
					$tag_ids[] = $tag->term_id;
				}
				$args['tag__in'] = $tag_ids;
			}
		}

		// Related posts based on categories.
		if ( 'categories' === $taxonomy ) {

			$categories = get_the_category( $post_id );

			if ( $categories ) {

				foreach ( $categories as $category ) {
					$category_ids[] = $category->term_id;
				}
				$args['category__in'] = $category_ids;
			}
		}

		$my_query = new WP_Query( $args );

		if ( $my_query->have_posts() ) {

			echo '<div class="' . esc_html( $main_classes ) . '">';

			echo ( 'full' === $position ) ? '<div class="container">' : '';

			echo '<div class="related-posts-title">';
				technologist_section_title( 'related_post_title' );
			echo '</div>';

			echo '<div class="related-posts-container clear">';

			while ( $my_query->have_posts() ) :
				$my_query->the_post();

				/**
				 * Add Related Post layouts.
				 *
				 * @args $post_layout -  posts layouts
				 */
				single_related_post( $post_layout );

				if ( ( 'rpost-4' === $post_layout || 'rpost-5' === $post_layout ) && 1 === ++$count ) {
					get_template_part( 'template-parts/related/related', 'ad' );
				}

			endwhile;

			wp_reset_postdata();

			echo '</div>';

			echo ( 'full' === $position ) ? '</div>' : '';

			echo '</div>';

		}

	}
}

if ( ! function_exists( 'technologist_social_buttons' ) ) {
	/**
	 * Display the Social Sharing buttons.
	 *
	 * @param string $buttons_pos position of social button.
	 */
	function technologist_social_buttons( $buttons_pos = 'floating' ) {

		$buttons        = [];
		$social_buttons = technologist_get_settings( 'mts_social_buttons' );
		$layout         = technologist_get_settings( 'social_button_layout' ) ? technologist_get_settings( 'social_button_layout' ) : 'default';

		if ( null !== $social_buttons && is_array( $social_buttons ) && array_key_exists( 'enabled', $social_buttons ) ) {
			$buttons = $social_buttons['enabled'];
		}
		if ( ! empty( $buttons ) ) {
			switch ( $layout ) {
				case 'default':
					?>
						<div class="shareit shareit-default <?php echo $buttons_pos; ?>">
							<?php
							foreach ( $buttons as $key => $button ) {
								technologist_social_button( $key );
							}
							?>
						</div>
					<?php
					break;

				case 'circular':
					?>
						<div class="shareit shareit-circular <?php echo $layout . ' ' . $buttons_pos; ?>">
							<?php
							foreach ( $buttons as $key => $button ) {
								technologist_social_circular_button( $key );
							}
							?>
						</div>
					<?php
					break;

				case 'standard':
					?>
						<div class="shareit shareit-circular <?php echo $layout . ' ' . $buttons_pos; ?>">
							<?php
							foreach ( $buttons as $key => $button ) {
								technologist_social_circular_button( $key );
							}
							?>
						</div>
					<?php
					break;

				default:
					?>
						<div class="shareit shareit-default <?php echo $buttons_pos; ?>">
							<?php
							foreach ( $buttons as $key => $button ) {
								technologist_social_button( $key );
							}
							?>
						</div>
					<?php
					break;
			}
		}
	}
}

if ( ! function_exists( 'technologist_social_button' ) ) {
	/**
	 * Display network-independent sharing buttons.
	 *
	 * @param string $button button name.
	 */
	function technologist_social_button( $button ) {
		$text = esc_html( get_the_title() );
		$link = rawurlencode( get_permalink() );
		switch ( $button ) {
			case 'facebookshare':
				?>
				<!-- Facebook Share-->
				<span class="share-item facebooksharebtn">
					<div class="fb-share-button" data-layout="button_count"></div>
				</span>
				<?php
				break;
			case 'twitter':
				?>
				<!-- Twitter -->
				<span class="share-item twitterbtn">
					<a href="https://twitter.com/share" class="twitter-share-button" data-via="<?php echo esc_attr( technologist_get_settings( 'mts_twitter_username' ) ); ?>"><?php esc_html_e( 'Tweet', 'technologist' ); ?></a>
				</span>
				<?php
				break;
			case 'facebook':
				?>
				<!-- Facebook -->
				<span class="share-item facebookbtn">
					<div id="fb-root"></div>
					<div class="fb-like" data-send="false" data-layout="button_count" data-width="150" data-show-faces="false"></div>
				</span>
				<?php
				break;
			case 'pinterest':
				?>
				<!-- Pinterest -->
				<span class="share-item pinbtn">
					<a href="http://pinterest.com/pin/create/button/?url=<?php the_permalink(); ?>&media=<?php $thumb = wp_get_attachment_image_src( get_post_thumbnail_id( get_the_ID() ), 'large' ); echo $thumb['0']; ?>&description=<?php the_title(); ?>" class="pin-it-button" count-layout="horizontal"><?php esc_html_e( 'Pin It', 'technologist' ); ?></a>
				</span>
				<?php
				break;
			case 'linkedin':
				?>
				<!--Linkedin -->
				<span class="share-item linkedinbtn">
					<script type="IN/Share" data-url="<?php echo esc_url( get_the_permalink() ); ?>"></script>
				</span>
				<?php
				break;
			case 'reddit':
				?>
				<!-- Reddit -->
				<span class="share-item reddit">
					<a href="//www.reddit.com/submit" onclick="javascript:window.open(this.href, '', 'menubar=no,toolbar=no,resizable=yes,scrollbars=yes,height=600,width=600');return false;"> <img src="<?php echo get_template_directory_uri() . '/images/reddit.png'; ?>" alt=<?php _e( 'submit to reddit', 'technologist' ); ?> border="0" /></a>
				</span>
				<?php
				break;
			case 'whatsapp':
				?>
				<!--WhatsApp -->
				<span class="share-item whatsapp">
					<a href="https://wa.me/?text=<?php echo $text . ' ' . $link; ?>" onclick="javascript:window.open(this.href, '', 'menubar=no,toolbar=no,resizable=yes,scrollbars=yes,height=600,width=600');return false;"><span class="icon"><i class="fa fa-whatsapp"></i></span><span class="social-text"><?php _e( 'WhatsApp', 'technologist' ); ?></span></a>
				</span>
				<?php
				break;
			case 'telegram':
				?>
				<!-- Telegram -->
					<span class="share-item telegram">
						<a href="javascript:window.open('https://telegram.me/share/url?url='+encodeURIComponent(window.location.href), '_blank')"><span class="icon"><i class="fa fa-paper-plane"></i></span><span class="social-text"><?php _e( 'Telegram', 'technologist' ); ?></span></a>
					</span>
				<?php
				break;
			case 'tumblr':
				?>
					<!-- Tumblr -->
					<span class="share-item tumblr">
						<a target="_blank" href="https://www.tumblr.com/widgets/share/tool?canonicalUrl=<?php echo $link; ?>&title=<?php echo $text; ?>"><span class="icon"><i class="fa fa-tumblr"></i></span><span class="social-text"><?php _e( 'Tumblr', 'technologist' ); ?></span></a>
					</span>
				<?php
				break;
			case 'pocket':
				?>
					<!-- Pocket -->
					<span class="share-item pocket">
						<a target="_blank" href="https://getpocket.com/save?url=<?php echo $link; ?>&title=<?php echo $text; ?>"><span class="icon"><i class="fa fa-get-pocket"></i></span><span class="social-text"><?php _e( 'Pocket', 'technologist' ); ?></span></a>
					</span>
				<?php
				break;
			case 'buffer':
				?>
				<!-- Buffer -->
					<span class="share-item buffer">
						<a target="_blank" href="https://bufferapp.com/add?url=<?php echo $link; ?>&amp;text=<?php echo $text; ?>"><span class="icon"><svg height="18px" id="Layer_1" style="enable-background:new 0 0 512 512;" version="1.1" viewBox="0 0 512 512" width="18px" xml:space="preserve" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink"><g><g><path d="M70.7,164.5l169.2,81.7c4.4,2.1,10.3,3.2,16.1,3.2s11.7-1.1,16.1-3.2l169.2-81.7c8.9-4.3,8.9-11.3,0-15.6L272.1,67.2    c-4.4-2.1-10.3-3.2-16.1-3.2s-11.7,1.1-16.1,3.2L70.7,148.9C61.8,153.2,61.8,160.2,70.7,164.5z"/><path d="M441.3,248.2c0,0-30.9-14.9-35-16.9s-5.2-1.9-9.5,0.1s-124.8,60.2-124.8,60.2c-4.5,2.1-10.3,3.2-16.1,3.2    s-11.7-1.1-16.1-3.2c0,0-117.3-56.6-122.8-59.3c-6-2.9-7.7-2.9-13.1-0.3c-5.6,2.7-33.4,16.1-33.4,16.1c-8.9,4.3-8.9,11.3,0,15.6    l169.2,81.7c4.4,2.1,10.3,3.2,16.1,3.2s11.7-1.1,16.1-3.2l169.2-81.7C450.2,259.5,450.2,252.5,441.3,248.2z"/></g><path d="M441.3,347.5c0,0-30.9-14.9-35-16.9s-5.2-1.9-9.5,0.1S272.1,391,272.1,391c-4.5,2.1-10.3,3.2-16.1,3.2s-11.7-1.1-16.1-3.2   c0,0-117.3-56.6-122.8-59.3c-6-2.9-7.7-2.9-13.1-0.3c-5.6,2.7-33.4,16.1-33.4,16.1c-8.9,4.3-8.9,11.3,0,15.6l169.2,81.7   c4.4,2.2,10.3,3.2,16.1,3.2s11.7-1.1,16.1-3.2l169.2-81.7C450.2,358.8,450.2,351.8,441.3,347.5z"/></g></svg></span><span class="social-text"><?php _e( 'Buffer', 'technologist' ); ?></span></a>
					</span>
				<?php
				break;
			case 'vkontakte':
				?>
					<!-- Vkontakte -->
					<span class="share-item vkontakte">
						<a target="_blank" href="http://vk.com/share.php?url=<?php echo $link; ?>&title=<?php echo $text; ?>"><span class="icon"><i class="fa fa-vk"></i></span><span class="social-text"><?php _e( 'VK', 'technologist' ); ?></span></a>
					</span>
				<?php
				break;
			case 'mix':
				?>
					<!-- Mix -->
					<span class="share-item mix">
						<a target="_blank" href="https://mix.com/add?url=<?php echo $link; ?>"><span class="icon"><svg height="18px" style="enable-background:new 0 0 512 512;" version="1.1" viewBox="0 0 512 512" width="18px" xml:space="preserve" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink"><g id="comp_x5F_217-mix"><g><path d="M26.001,54.871v358.246c0,57.705,90.357,59.656,90.357,0V168.124c8.11-54.316,90.357-51.749,90.357,6.675v179.994    c0,59.453,98.57,59.556,98.57,0V235.584c5.44-56.166,90.357-53.906,90.357,4.415v24.44c0,61.503,90.355,58.114,90.355,0V54.871    H26.001z"/></g></g><g id="Layer_1"/></svg></span><span class="social-text"><?php _e( 'Mix', 'technologist' ); ?></span></a>
					</span>
				<?php
				break;
		}
	}
}
/**
 * Display network-independent sharing buttons.
 *
 * @param $button
 */
if ( ! function_exists( 'technologist_social_circular_button' ) ) {
	function technologist_social_circular_button( $button ) {
		global $post;
		$text = esc_html( get_the_title() );
		$link = rawurlencode( get_permalink() );
		if ( is_single() ) {
			$img_url = '';
			$img     = '';
			if ( has_post_thumbnail( $post->ID ) ) {
				$img     = wp_get_attachment_image_src( get_post_thumbnail_id( $post->ID ), 'technologist-featuredfull' );
				$img_url = $img[0];
			}
		}
		switch ( $button ) {
			case 'facebookshare':
				?>
				<!-- Facebook -->
				<a href="//www.facebook.com/share.php?m2w&s=100&p[url]=<?php echo rawurlencode( get_permalink() ); ?>&p[images][0]=<?php echo rawurlencode( $img_url[0] ); ?>&p[title]=<?php echo rawurlencode( get_the_title() ); ?>&u=<?php echo rawurlencode( get_permalink() ); ?>&t=<?php echo rawurlencode( get_the_title() ); ?>" class="facebooksharebtn" onclick="javascript:window.open(this.href, '', 'menubar=no,toolbar=no,resizable=yes,scrollbars=yes,height=600,width=600');return false;"><span class="social-icon"><i class="fa fa-facebook"></i></span></a>
				<?php
				break;
			case 'twitter':
				?>
				<!-- Twitter -->
				<?php
				$via = '';
				if ( technologist_get_settings( 'mts_twitter_username' ) ) {
					$via = '&via=' . technologist_get_settings( 'mts_twitter_username' );
				}
				?>
				<a href="https://twitter.com/intent/tweet?original_referer=<?php echo rawurlencode( get_permalink() ); ?>&text=<?php echo get_the_title(); ?>&url=<?php echo rawurlencode( get_permalink() ); ?><?php echo $via; ?>" class="twitterbutton" onclick="javascript:window.open(this.href, '', 'menubar=no,toolbar=no,resizable=yes,scrollbars=yes,height=600,width=600');return false;"><span class="social-icon"><i class="fa fa-twitter"></i></span></a>
				<?php
				break;

			case 'pinterest':
				global $post;
				?>
				<!-- Pinterest -->
				<?php $pinterestimage = wp_get_attachment_image_src( get_post_thumbnail_id( $post->ID ), 'full' ); ?>
				<a href="http://pinterest.com/pin/create/button/?url=<?php echo rawurlencode( get_permalink( $post->ID ) ); ?>&media=<?php echo $pinterestimage[0]; ?>&description=<?php the_title(); ?>" class="share-pinbtn" onclick="javascript:window.open(this.href, '', 'menubar=no,toolbar=no,resizable=yes,scrollbars=yes,height=600,width=600');return false;"><span class="social-icon"><i class="fa fa-pinterest"></i></span></a>
				<?php
				break;
			case 'linkedin':
				?>
				<!--Linkedin -->
				<a href="//www.linkedin.com/shareArticle?mini=true&url=<?php echo rawurlencode( get_permalink() ); ?>&title=<?php echo get_the_title(); ?>&source=<?php echo 'url'; ?>" class="linkedinbtn" onclick="javascript:window.open(this.href, '', 'menubar=no,toolbar=no,resizable=yes,scrollbars=yes,height=600,width=600');return false;"><span class="social-icon"><i class="fa fa-linkedin"></i></span><span class="social-text"><?php _e( 'Share', 'technologist' ); ?></span></a>
				<?php
				break;
			case 'reddit':
				?>
				<!-- Reddit -->
				<a href="//www.reddit.com/submit" class="reddit" onclick="javascript:window.open(this.href, '', 'menubar=no,toolbar=no,resizable=yes,scrollbars=yes,height=600,width=600');return false;"><span class="social-icon"><i class="fa fa-reddit-alien"></i></span></a>
				<?php
				break;
			case 'whatsapp':
				?>
				<!--WhatsApp -->
				<a href="https://wa.me/?text=<?php echo $text . ' ' . $link; ?>" class="whatsapp" onclick="javascript:window.open(this.href, '', 'menubar=no,toolbar=no,resizable=yes,scrollbars=yes,height=600,width=600');return false;"><span class="social-icon"><i class="fa fa-whatsapp"></i></span></a>
				<?php
				break;
			case 'telegram':
				?>
				<!-- Telegram -->
				<a href="javascript:window.open('https://telegram.me/share/url?url='+encodeURIComponent(window.location.href), '_blank')" class="telegram"><span class="social-icon"><i class="fa fa-paper-plane"></i></span></a>
				<?php
				break;
			case 'tumblr':
				?>
				<!-- Tumblr -->
				<a target="_blank" href="https://www.tumblr.com/widgets/share/tool?canonicalUrl=<?php echo $link; ?>&title=<?php echo $text; ?>" class="tumblr"><span class="social-icon"><i class="fa fa-tumblr"></i></span></a>
				<?php
				break;
			case 'pocket':
				?>
				<!-- Pocket -->
				<a target="_blank" href="https://getpocket.com/save?url=<?php echo $link; ?>&title=<?php echo $text; ?>" class="pocket"><span class="social-icon"><i class="fa fa-get-pocket"></i></span></a>
				<?php
				break;
			case 'buffer':
				?>
				<!-- Buffer -->
				<a target="_blank" href="https://bufferapp.com/add?url=<?php echo $link; ?>&amp;text=<?php echo $text; ?>" class="buffer"><span class="social-icon"><svg height="18px" id="Layer_1" style="enable-background:new 0 0 512 512;" version="1.1" viewBox="0 0 512 512" width="18px" xml:space="preserve" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink"><g><g><path d="M70.7,164.5l169.2,81.7c4.4,2.1,10.3,3.2,16.1,3.2s11.7-1.1,16.1-3.2l169.2-81.7c8.9-4.3,8.9-11.3,0-15.6L272.1,67.2    c-4.4-2.1-10.3-3.2-16.1-3.2s-11.7,1.1-16.1,3.2L70.7,148.9C61.8,153.2,61.8,160.2,70.7,164.5z"/><path d="M441.3,248.2c0,0-30.9-14.9-35-16.9s-5.2-1.9-9.5,0.1s-124.8,60.2-124.8,60.2c-4.5,2.1-10.3,3.2-16.1,3.2    s-11.7-1.1-16.1-3.2c0,0-117.3-56.6-122.8-59.3c-6-2.9-7.7-2.9-13.1-0.3c-5.6,2.7-33.4,16.1-33.4,16.1c-8.9,4.3-8.9,11.3,0,15.6    l169.2,81.7c4.4,2.1,10.3,3.2,16.1,3.2s11.7-1.1,16.1-3.2l169.2-81.7C450.2,259.5,450.2,252.5,441.3,248.2z"/></g><path d="M441.3,347.5c0,0-30.9-14.9-35-16.9s-5.2-1.9-9.5,0.1S272.1,391,272.1,391c-4.5,2.1-10.3,3.2-16.1,3.2s-11.7-1.1-16.1-3.2   c0,0-117.3-56.6-122.8-59.3c-6-2.9-7.7-2.9-13.1-0.3c-5.6,2.7-33.4,16.1-33.4,16.1c-8.9,4.3-8.9,11.3,0,15.6l169.2,81.7   c4.4,2.2,10.3,3.2,16.1,3.2s11.7-1.1,16.1-3.2l169.2-81.7C450.2,358.8,450.2,351.8,441.3,347.5z"/></g></svg></span></a>
				<?php
				break;
			case 'vkontakte':
				?>
				<!-- Vkontakte -->
				<a target="_blank" href="http://vk.com/share.php?url=<?php echo $link; ?>&title=<?php echo $text; ?>" class="vkontakte"><span class="social-icon"><i class="fa fa-vk"></i></span></a>
				<?php
				break;
			case 'mix':
				?>
				<!-- Mix -->
				<a target="_blank" href="https://mix.com/add?url=<?php echo $link; ?>" class="mix"><span class="social-icon"><svg height="18px" style="enable-background:new 0 0 512 512;" version="1.1" viewBox="0 0 512 512" width="18px" xml:space="preserve" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink"><g id="comp_x5F_217-mix"><g><path d="M26.001,54.871v358.246c0,57.705,90.357,59.656,90.357,0V168.124c8.11-54.316,90.357-51.749,90.357,6.675v179.994    c0,59.453,98.57,59.556,98.57,0V235.584c5.44-56.166,90.357-53.906,90.357,4.415v24.44c0,61.503,90.355,58.114,90.355,0V54.871    H26.001z"/></g></g><g id="Layer_1"/></svg></span></a>
				<?php
				break;
		}
	}
}

if ( ! function_exists( 'technologist_blog_articles' ) ) {
	/**
	 * Display a post of specific layout.
	 */
	function technologist_blog_articles() {

		$is_excerpt_on  = technologist_get_settings( 'archive_show_excerpt' );
		$excerpt_length = technologist_get_settings( 'archive_excerpt_length' );

		?>
		<article <?php post_class( 'latestPost excerpt clearfix' ); ?> id="post-<?php the_ID(); ?>">

			<?php technologist_post_thumbnail(); ?>

			<div class="wrapper">

				<header>
					<?php

					technologist_the_post_meta( 'archive', 'top' );

					technologist_post_title();

					technologist_the_post_meta( 'archive', 'bottom' );

					?>
				</header>

				<?php technologist_post_content( $is_excerpt_on, $excerpt_length ); ?>

			</div>

		</article>
		<?php
	}
}

if ( ! function_exists( 'detect_adblocker_notice' ) ) {
	/**
	 * Detect Adblocker Notice
	 */
	function detect_adblocker_notice() {
		?>
		<div class="blocker-notice">
			<i class="fa fa-exclamation"></i>
			<h4><?php echo technologist_get_settings( 'detect_adblocker_title' ); //phpcs:ignore ?></h4>
			<p><?php echo technologist_get_settings( 'detect_adblocker_description' ); //phpcs:ignore ?></p>
			<div><a href="" class="refresh-button"><?php esc_html_e( 'Refresh', 'technologist' ); ?></a></div>
		</div>
		<?php
	}
}

if ( ! function_exists( 'show_section_on' ) ) {
	/**
	 * Show Section on selected page.
	 *
	 * @param string $page page where section show on.
	 */
	function show_section_on( $page = 'all' ) {

		$hash = [
			'all'    => true,
			'home'   => is_home(),
			'single' => is_single(),
			'page'   => is_page(),
			'both'   => is_home() || is_single(),
		];

		return isset( $hash[ $page ] ) && $hash[ $page ] ? true : false;

	}
}

if ( ! function_exists( 'technologist_featured_layouts' ) ) {
	/**
	 * Blog Posts layouts.
	 */
	function technologist_featured_layouts() {
		include_once get_parent_theme_file_path( 'includes/class-technologist-featured-layouts.php' );
		technologist()->featured_layouts = new Technologist_Featured_Layouts();
		technologist()->featured_layouts->render();
	}
}
